// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
import Foundation

public extension Date {
    func weekNumberAfterBirthDate() -> Int? {
        guard let daysSinceBirth = Calendar.current.dateComponents([.day], from: self, to: Date()).day else {
            return nil
        }
        return Int((Double(daysSinceBirth)/7.0) + 1) // Date of birth should be week one (thus +1)!
    }

    func date(byAdding component: Calendar.Component, value: Int) -> Date? {
        Calendar.current.date(byAdding: component, value: value, to: self)
    }

    func isBefore(_ date: Date) -> Bool {
        !isAfterOrEqual(date)
    }

    func isAfterOrEqual(_ date: Date) -> Bool {
        timeIntervalSince(date) >= 0
    }

    func isAfterOrEqualToNow() -> Bool {
        timeIntervalSinceNow >= 0
    }

    /// Determiens whether the receiver is between `date1` and `date2`.
    /// The interval is defined as: `[date1;date2[`
    /// A `nil` parameter will work as an infinite value in the direction it is passed for, e.g. for `date1=nil` => `]∞;date2[`
    func isBetween(date1: Date?, date2: Date?) -> Bool {
        guard let date1 = date1 else {
            guard let date2 = date2 else {
                return true // nil & nil => in between
            }
            return isBefore(date2) // nil & before date => in between
        }
        guard let date2 = date2 else {
            return isAfterOrEqual(date1) // after date & nil => in between
        }
        return isAfterOrEqual(date1) && isBefore(date2) // after date & before date => in between
    }

    var year: Int {
        Calendar.current.component(.year, from: self)
    }

    var month: Int {
        Calendar.current.component(.month, from: self)
    }
}
