// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import XCTest
import DeviceKit
import UIKit
@testable import AppleExtensions

final class UIApplicationTests: XCTestCase {

    // Unfortunately, we cannot test the `.present` method, since the system fails to present the view controllers in a unit test
    func testTopViewController() {
        let window = UIWindow()
        let tabBarController = UITabBarController()
        window.rootViewController = tabBarController
        XCTAssertEqual(tabBarController, UIApplication.topViewController(controller: window.rootViewController))

        let viewController1 = UIViewController()
        viewController1.title = "1"
        let navCon = UINavigationController(rootViewController: viewController1)
        let viewController2 = UIViewController()
        viewController2.title = "2"
        tabBarController.viewControllers = [ navCon, viewController2 ]
        tabBarController.selectedIndex = 0

        XCTAssertEqual(viewController1, UIApplication.topViewController(controller: window.rootViewController))
        tabBarController.selectedIndex = 1
        XCTAssertEqual(viewController2, UIApplication.topViewController(controller: window.rootViewController))

        let viewController3 = UIViewController()
        navCon.pushViewController(viewController3, animated: false)
        tabBarController.selectedIndex = 0
        XCTAssertEqual(viewController3, UIApplication.topViewController(controller: window.rootViewController))
    }
}
