// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation

public struct SearchResultDTO: Codable {
    
    enum CodingKeys: String, CodingKey {
        case id
        case title
        case sortPoints
        case categoryName
        case categoryId
        case categoryIcon
        case tagTitle
        case content
        case weeks
        case articleId
        case articleName
    }
 
    public let id: Int
    public let title: String
    public let sortPoints: Int
    public let categoryName: String
    public let categoryId: Int
    public let categoryIcon: String
    public let tagTitle: String
    public let content: String
    public let weeks: [String]?
    public let articleId: Int?
    public let articleName: String?
    
    public init(id: Int, title: String, sortPoints: Int, categoryName: String, categoryId: Int, categoryIcon: String, tagTitle: String, content: String, weeks: [String]?, articleId: Int?, articleName: String?) {
        self.id = id
        self.title = title
        self.sortPoints = sortPoints
        self.categoryName = categoryName
        self.categoryId = categoryId
        self.categoryIcon = categoryIcon
        self.tagTitle = tagTitle
        self.content = content
        self.weeks = weeks
        self.articleId = articleId
        self.articleName = articleName
    }
}

public extension SearchResultDTO {
    
    var unwrappedArticleId: Int {
        if let articleId = articleId {
            return articleId
        }
        return id
    }
    
    var sectionId: Int? {
        if articleId != nil { return id }
        return nil
    }
}
