// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation

/// Contains the stub results for URLs
public struct URLSessionStubResults {
    /// Contains stub results for specific URLs, which will be used when mocking `URLSession` via `URLSessionMockProtocol`
    public static var resultsForUrls: [URL?: URLSessionStubResult] = [:]

    /// Resets the stub storage
    public static func reset() {
        resultsForUrls.removeAll()
    }
}

/// Stub results for `URLSession` mocking via `URLSessionMockProtocol`
public struct URLSessionStubResult {
    public let response: URLResponse?
    public let error: NSError?
    public let data: Data?

    /// Private init to make sure that we don't create unrealistic setups
    private init(response: URLResponse?, error: NSError?, data: Data?) {
        self.response = response
        self.error = error
        self.data = data
    }

    /// Stub for successful networkRequest with response and data
    public static func dataResponse(data: Data, response: URLResponse) -> URLSessionStubResult {
        URLSessionStubResult(
            response: response,
            error: nil,
            data: data
        )
    }

    /// Creates stub for failing network request, e.g. network problems.
    public static func error(error: NSError) -> URLSessionStubResult {
        URLSessionStubResult(
            response: nil,
            error: error,
            data: nil
        )
    }
}
