// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import XCTest
@testable import HTTPMockHelpers

final class URLSessionMockTests: XCTestCase {
    let mockSession: URLSession = .mockSession

    func testDataResponse() {
        URLSessionStubResults.reset()
        let url = URL(string: "mock://test.com/data")
        URLSessionStubResults.resultsForUrls[url] = .dataResponse(
            data: "MyData".data(using: .utf8)!,
            response: URLSessionStubResponses.response(url: url!)!
        )

        let expect = XCTestExpectation()
        mockSession.dataTask(with: url!) { (data, response, error) in
            XCTAssertNil(error)
            XCTAssertEqual(200, (response as? HTTPURLResponse)?.statusCode)
            XCTAssertEqual("MyData", String(data: data!, encoding: .utf8))
            expect.fulfill()
        }.resume()
        wait(for: [expect], timeout: 1.0)
    }

    func testError() {
        URLSessionStubResults.reset()
        let url = URL(string: "mock://test.com/error")

        URLSessionStubResults.resultsForUrls[url] = .error(
            error: NSError(domain: "TestDomain", code: 1337, userInfo: nil)
        )

        let expect = XCTestExpectation()
        mockSession.dataTask(with: url!) { (data, response, error) in
            XCTAssertEqual((error! as NSError).code, 1337)
            XCTAssertNil(response)
            XCTAssertNil(data)
            expect.fulfill()
        }.resume()
        wait(for: [expect], timeout: 1.0)
    }
}

private enum TestError : Error {
    case fail
}
