// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import HTTPMockHelpers
import XCTest
import Combine
@testable import HTTPNetworking

final class NetworkSessionTests: XCTestCase {

    let session: NetworkSession = URLSession.mockSession
    let baseUrl = "http://example.com"
    private var cancelBag = Set<AnyCancellable>()

    override class func setUp() {
        super.setUp()
        HTTPNetworkingConfig.isDebugPrintingEnabled = true
    }

    func testDataTaskPublisher() {
        let request = TestRequest(
            baseUrl: baseUrl,
            pathComponents: ["test", "mock"],
            method: .get,
            query: nil,
            body: nil,
            headers: [:]
        )

        let url = URL(string: "\(baseUrl)/test/mock")
        URLSessionStubResults.resultsForUrls[url] = .dataResponse(
            data: "{\"title\":\"Test\",\"text\":\"Text\"}".data(using: .utf8)!,
            response: URLSessionStubResponses.response(url: url!)!
        )

        let expect = XCTestExpectation()
        session.dataTaskPublisher(for: request)
            .sink(
                receiveCompletion: { completion in
                    switch completion {
                    case .failure:
                        XCTFail("Should not fail!")
                    case .finished:
                        expect.fulfill()
                    }
                },
                receiveValue: { response in
                    XCTAssertEqual("Test", response.example.title)
                    XCTAssertEqual("Text", response.example.text)
                }
            )
            .store(in: &cancelBag)
        wait(for: [expect], timeout: 1.0)
    }
}
