// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import os.log

/// Configuration model for `TriforkLogger`
public struct OSLoggerConfig {

    /// Public initializer
    public init(defaultCategory: String, minimumLogLevel: LogLevel, isDevelopmentInfoEnabled: Bool, isEmojisEnabled: Bool, isSuspended: Bool = false) {
        self.defaultCategory = defaultCategory
        self.minimumLogLevel = minimumLogLevel
        self.isDevelopmentInfoEnabled = isDevelopmentInfoEnabled
        self.isEmojisEnabled = isEmojisEnabled
        self.isSuspended = isSuspended
    }

    /// Sets the default category, that is used for `os_log` if none is specified for a log message
    public var defaultCategory: String

    /// Sets the minimum logLevel that you wish to see printed.
    public var minimumLogLevel: LogLevel

    /// Enables/disables development information in log messages, such as file name, line number and function name.
    public var isDevelopmentInfoEnabled: Bool

    /// Enables/disables emojis for log levels.
    public var isEmojisEnabled: Bool

    /// Suspends all actions by TriforkLogger - no logging will be performed
    public var isSuspended: Bool = false

    /// The default configuration for `TriforkLogger`
    /// category: `"default"`
    /// minmumLogLevel: `.default`
    /// printDevelopmentInfo: `false`
    /// listener: `nil`
    /// isEmojisEnabled: `true`
    public static func `default`() -> OSLoggerConfig {
        return OSLoggerConfig(
            defaultCategory: "default",
            minimumLogLevel: .debug,
            isDevelopmentInfoEnabled: false,
            isEmojisEnabled: true
        )
    }
}
