// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import UIKit

@main
class AppDelegate: UIResponder, UIApplicationDelegate {

    @DI private var logger: Logger
    private var allowedOrientationMask: UIInterfaceOrientationMask = .portrait

    func application(_ application: UIApplication, didFinishLaunchingWithOptions launchOptions: [UIApplication.LaunchOptionsKey: Any]?) -> Bool {
        if !App.isUnitTesting {
            App.buildDependencies()
            logger.debug("Launching app...")
            Appearances.setup()
        } else {
            App.setupMockFailRisk()
        }
        return true
    }

    // MARK: UISceneSession Lifecycle

    func application(_ application: UIApplication, configurationForConnecting connectingSceneSession: UISceneSession, options: UIScene.ConnectionOptions) -> UISceneConfiguration {
        // Called when a new scene session is being created.
        // Use this method to select a configuration to create the new scene with.
        return UISceneConfiguration(name: "Default Configuration", sessionRole: connectingSceneSession.role)
    }

    func application(_ application: UIApplication, didDiscardSceneSessions sceneSessions: Set<UISceneSession>) {
        // Called when the user discards a scene session.
        // If any sessions were discarded while the application was not running, this will be called shortly after application:didFinishLaunchingWithOptions.
        // Use this method to release any resources that were specific to the discarded scenes, as they will not return.
    }

    func application(_ application: UIApplication, supportedInterfaceOrientationsFor window: UIWindow?) -> UIInterfaceOrientationMask {
        allowedOrientationMask
    }

    // MARK: - Custom AppDelegate business 👨🏻‍💼

    private let orientationValueKey: String = "orientation"
    
    func forceOrientationChange(_ orientation: UIInterfaceOrientationMask) {
        let shouldGoIntoLandscape: Bool = UIDevice.current.orientation.isPortrait || UIDevice.current.orientation.isFlat || UIDevice.current.orientation == .unknown
        switch orientation {
        case [.landscapeLeft, .landscapeRight] where shouldGoIntoLandscape,
             .landscape where shouldGoIntoLandscape:
            // Force device into landscape - it's not pretty, but needed to get the job done.
            UIDevice.current.setValue(App.preferredLandscapeOrientation.rawValue, forKey: orientationValueKey)
        case .landscape where UIDevice.current.orientation.isLandscape:
            UIDevice.current.setValue(UIDevice.current.orientation.rawValue, forKey: orientationValueKey)
        case .portrait:
            UIDevice.current.setValue(UIInterfaceOrientation.portrait.rawValue, forKey: orientationValueKey)
        default:
            logger.error("This is an undefined orientation case, which is not supported by the current implementation! (\(orientation.rawValue))")
            UIDevice.current.setValue(UIInterfaceOrientation.portrait.rawValue, forKey: orientationValueKey) //Fallback to portrait
        }

        allowedOrientationMask = orientation
        UIViewController.attemptRotationToDeviceOrientation()
    }
}
