// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Combine
import DependencyInjection
import HTTPNetworking
import SharedServices
import GMAppData
import ErrorData
import Foundation
import Logger

public class CarePlanServiceImpl: CarePlanService {
    @Inject private var logger: LoggerProtocol
    
    public init() { }
    
    public func fetchCarePlan() -> AnyPublisher<CarePlan?, ServiceError> {
        var result: CarePlan?
        
        let jsonData = readLocalJSONFile(forName: "carePlanTemplate")
        if let data = jsonData {
            if let carePlan = parseJSONFile(data) {
                result = carePlan
            }
        }
        return Just(result)
            .setFailureType(to: ServiceError.self)
            .eraseToAnyPublisher()
    }
    
    func readLocalJSONFile(forName name: String) -> Data? {
        do {
            if let filePath = Bundle.main.path(forResource: name, ofType: "json") {
                let fileUrl = URL(fileURLWithPath: filePath)
                let data = try Data(contentsOf: fileUrl)
                return data
            }
        } catch {
            logger.debug("Error reading locale JSON file: \(error.localizedDescription)")
        }
        return nil
    }
    
    func parseJSONFile(_ jsonData: Data) -> CarePlan? {
        let decoder: JSONDecoder = .iso8601()
        
        do {
            let decodedData = try decoder.decode(CarePlan.self, from: jsonData)
            return decodedData
        } catch {
            logger.debug("Error decoding locale JSON file: \(error.localizedDescription)")
        }
        return nil
    }
}
