// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import Combine
import SharedServices
import GMAppData
import ErrorData

public class CarePlanServiceMock: CarePlanService {
    
    public init() { }
    
    public func fetchCarePlan() -> AnyPublisher<CarePlan?, ServiceError> {
        let carePlan = CarePlan(activities: [
            Activity(scheduledString: "uge 10-12",
                     title: "Undersøgelse",
                     description: "Dette er en beskrivelse af en udersøgelse",
                     untilWeek: 12,
                     performer: .hospital,
                     id: UUID().uuidString,
                     isAfterBirth: false),
            Activity(scheduledString: "uge 14",
                     title: "Undersøgelse 2",
                     description: "Dette er en beskrivelse af en anden udersøgelse",
                     untilWeek: 14,
                     performer: .doctor,
                     id: UUID().uuidString,
                     isAfterBirth: false),
            Activity(scheduledString: "uge 18",
                     title: "Undersøgelse 3",
                     description: "Dette er en beskrivelse af en tredje udersøgelse",
                     untilWeek: 18,
                     performer: .doctor,
                     id: UUID().uuidString,
                     isAfterBirth: false),
        ])
        
        return MockPublisher.mockFailable(
            value: carePlan,
            error: ServiceError.networkError(.missingInternetConnection)
        )
    }
}
