//// The MIT License
////
//// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
////
//// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
////
//// Permission is hereby granted, free of charge, to any person obtaining a copy of
//// this software and associated documentation files (the "Software"), to deal in
//// the Software without restriction, including without limitation the rights to
//// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
//// of the Software, and to permit persons to whom the Software is furnished to do
//// so, subject to the following conditions:
////
//// The above copyright notice and this permission notice shall be included in all
//// copies or substantial portions of the Software.
////
//// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
//// SOFTWARE.
//
//import Foundation
//import GMAppData
//import MaternityServices
//import Combine
//import ErrorData
//import CMSServices
//import UIData
//
//final class PersonalDataServiceImpl: PersonaDataService {
//    @DI private var dictionaryService: DictionaryService
//    @DI private var maternityEnvironmentStore: MaternityDataEnvironmentStore
//    
//    func fetchContactInformation() -> AnyPublisher<[KeyValueModel], ServiceError> {
//        let personalData = maternityEnvironmentStore.selectedMaternity?.personalDataSection
//        
//        let data = [
//            KeyValueModel.dictionaryModel(
//                title: Localizable.journal_section_personal_data_personal_cpr(),
//                primaryValue: personalData?.cpr
//            ),
//            
//            KeyValueModel.dictionaryModel(
//                title: Localizable.journal_section_personal_data_personal_name(),
//                primaryValue: personalData?.name?.fullName
//            ),
//            
//            KeyValueModel.dictionaryModel(
//                title: Localizable.journal_section_personal_data_personal_address(),
//                primaryValue: personalData?.address?.streetAndNumber),
//            
//            KeyValueModel.dictionaryModel(
//                title: Localizable.journal_section_personal_data_personal_zip(),
//                primaryValue: personalData?.address?.zip
//            ),
//
//            KeyValueModel.dictionaryModel(
//                title: Localizable.journal_section_personal_data_personal_city(),
//                primaryValue: personalData?.address?.city
//            ),
//            
//            KeyValueModel.dictionaryModel(
//                title: Localizable.journal_section_personal_data_personal_phonenumber_mobile(),
//                primaryValue: personalData?.telecoms?.mobile
//            ),
//            
//            KeyValueModel.dictionaryModel(
//                title: Localizable.journal_section_personal_data_personal_phonenumber_home(),
//                primaryValue: personalData?.telecoms?.home
//            ),
//            
//            KeyValueModel.dictionaryModel(
//                title: Localizable.journal_section_personal_data_personal_phonenumber_work(),
//                primaryValue: personalData?.telecoms?.work
//            ),
//            
//            personalData?.temporaryAddress?.fullAddressAsSingleLine != nil ?
//                KeyValueModel.dictionaryModel(
//                    title: Localizable.journal_section_personal_data_personal_temporary_adress(),
//                    primaryValue: personalData?.temporaryAddress?.fullAddressAsSingleLine
//                ) : nil,
//            
//            personalData?.temporaryAddress?.duration != nil ?
//                KeyValueModel.dictionaryModel(
//                    title: Localizable.journal_section_personal_data_personal_temporary_adress_duration(),
//                    primaryValue: personalData?.temporaryAddress?.duration
//                ) : nil
//            
//        ]
//        .compactMap { $0 }
//        
//        return Just(data)
//            .mapToServiceError()
//            .eraseToAnyPublisher()
//    }
//    
//    func fetchLifeTogetherAndHome() -> AnyPublisher<[KeyValueModel], ServiceError> {
//        let socialHistory = maternityEnvironmentStore.selectedMaternity?.socialHistorySection
//        let childPartnerSection = maternityEnvironmentStore.selectedMaternity?.childPartnerSection
//        
//        return dictionaryService.fetchDictionaryWithEmptyFallback()
//            .map { dictionary -> [KeyValueModel] in
//                [
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_section_personal_data_practical_partnership_status(),
//                        primaryValue: socialHistory?.maritalOrPartnershipStatus?.description,
//                        dictionary: dictionary
//                    ),
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_section_personal_data_practical_living_conditions(),
//                        primaryValue: socialHistory?.livingConditions?.description,
//                        dictionary: dictionary
//                    ),
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_section_personal_data_practical_partners_name(),
//                        primaryValue: childPartnerSection?.name?.fullName,
//                        dictionary: dictionary
//                    )
//                ]
//            }
//            .mapToServiceError()
//            .eraseToAnyPublisher()
//    }
//
//    func fetchNationalityAndLanguage() -> AnyPublisher<[KeyValueModel], ServiceError> {
//        let languageSection = maternityEnvironmentStore.selectedMaternity?.languageSection
//
//        return dictionaryService.fetchDictionaryWithEmptyFallback()
//            .map { dictionary -> [KeyValueModel] in
//                [
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_section_personal_data_practical_nationality(),
//                        primaryValue: languageSection?.nationality,
//                        dictionary: dictionary
//                    ),
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_section_personal_data_practical_need_translator(),
//                        primaryValue: languageSection?.translationRequirements?.needsTranslation?.description,
//                        dictionary: dictionary
//                    ),
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_section_personal_data_practical_translator_language(),
//                        primaryValue: languageSection?.translationRequirements?.language,
//                        dictionary: dictionary
//                    ),
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_section_personal_data_practical_additional_info(),
//                        primaryValue: languageSection?.additionalInformations,
//                        dictionary: dictionary
//                    )
//                ]
//            }
//            .mapToServiceError()
//            .eraseToAnyPublisher()
//    }
//    
//    func fetchNextOfKin() -> AnyPublisher<[KeyValueModelGroup], ServiceError> {
//        let nextOfKins = (maternityEnvironmentStore.selectedMaternity?.personalDataSection?.nextOfKin ?? []).emptyFallback()
//
//        let data = nextOfKins.enumerated().map { enumerator -> KeyValueModelGroup in
//            KeyValueModelGroup(
//                title: Localizable.journal_section_personal_data_next_of_kin_title(
//                    nextOfKins.count == 1 ? "" : "\(enumerator.offset + 1)"
//                ),
//                keyValueModels: [
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_section_personal_data_next_of_kin_name(),
//                        primaryValue: enumerator.element.name?.fullName
//                    ),
//                    
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_section_personal_data_next_of_kin_relation(),
//                        primaryValue: enumerator.element.relation?.description
//                    ),
//                    
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_section_personal_data_next_of_kin_phonenumber_mobile(),
//                        primaryValue: enumerator.element.telecoms?.mobile
//                    ),
//                    
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_section_personal_data_next_of_kin_phonenumber_home(),
//                        primaryValue: enumerator.element.telecoms?.home
//                    ),
//                    
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_section_personal_data_next_of_kin_phonenumber_work(),
//                        primaryValue: enumerator.element.telecoms?.work
//                    ),
//                    
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_section_personal_data_next_of_kin_additional_info(),
//                        primaryValue: enumerator.element.additionalInformation
//                    )
//                ])
//        }
//        
//        return Just(data)
//            .mapToServiceError()
//            .eraseToAnyPublisher()
//    }
//}
