//// The MIT License
////
//// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
////
//// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
////
//// Permission is hereby granted, free of charge, to any person obtaining a copy of
//// this software and associated documentation files (the "Software"), to deal in
//// the Software without restriction, including without limitation the rights to
//// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
//// of the Software, and to permit persons to whom the Software is furnished to do
//// so, subject to the following conditions:
////
//// The above copyright notice and this permission notice shall be included in all
//// copies or substantial portions of the Software.
////
//// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
//// SOFTWARE.
//
//import MaternityServices
//import GMAppData
//import CMSServices
//import Combine
//import ErrorData
//import CMSData
//import Foundation
//import UIData
//
//final class PreviousPregnanciesServiceImpl: PreviousPregnanciesService {
//    @DI private var maternityEnvironmentStore: MaternityDataEnvironmentStore
//    @DI private var dictionaryService: DictionaryService
//    
//    func fetchPreviousPregnancies(force: Bool = false) -> AnyPublisher<PreviousPregnancies, ServiceError> {        
//        if force { maternityEnvironmentStore.clear() }
//        
//        return maternityEnvironmentStore.requestUpdate()
//            .flatMap { _  -> AnyPublisher<PreviousPregnancies, ServiceError> in
//                let dataCard = self.maternityEnvironmentStore.selectedMaternity
//                return self.dictionaryService.fetchDictionary()
//                    .map { dictionary -> PreviousPregnancies in
//                        let previousBirths: [PreviousBirthsSectionAllOfBirths] = (dataCard?.previousBirthsSection?.births ?? []).emptyFallback()
//                        let previousAbortions: [PreviousAbortionsSectionAllOfAbortions] = (dataCard?.previousAbortionsSection?.abortions ?? []).emptyFallback()
//
//                        return PreviousPregnancies(
//                            abortions: previousAbortions.map { self.mapAbortion($0, dictionary: dictionary) },
//                            births: previousBirths.map { self.mapBirth($0, dictionary: dictionary) }
//                        )
//                    }
//                    .mapToServiceError()
//                    .eraseToAnyPublisher()
//            }
//            .mapToServiceError()
//            .eraseToAnyPublisher()
//        }
//  
//
//    
//    private func mapBirth(_ birth: PreviousBirthsSectionAllOfBirths, dictionary: CMSDictionary) -> Birth {
//        Birth(
//            year: birth.year?.description ?? Localizable.common_missing_data(),
//            table: birth.children?.map { mapChild($0, birth: birth, dictionary: dictionary) } ?? [],
//            info: [
//                KeyValueModel.dictionaryModel(
//                    title: Localizable.journal_section_previous_births_child_year(),
//                    primaryValue: birth.year?.description,
//                    dictionary: dictionary
//                ),
//                KeyValueModel.dictionaryModel(
//                    title: Localizable.journal_section_previous_births_child_gestation_length(),
//                    primaryValue: birth.gestationLengthString,
//                    dictionary: dictionary
//                ),
//                KeyValueModel.dictionaryModel(
//                    title: Localizable.journal_section_previous_births_child_place_of_birth(),
//                    primaryValue: birth.birthPlace,
//                    dictionary: dictionary
//                ),
//                KeyValueModel.dictionaryModel(
//                    title: Localizable.journal_section_previous_births_child_subjective_experience(),
//                    primaryValue: birth.subjectiveBirthExperience?.description,
//                    dictionary: dictionary
//                ),
//                KeyValueModel.dictionaryModel(
//                    title: Localizable.journal_section_previous_births_pregnancy_summary(),
//                    primaryValue: birth.pregnancySummary,
//                    dictionary: dictionary
//                ),
//                KeyValueModel.dictionaryModel(
//                    title: Localizable.journal_section_previous_births_birth_summary(),
//                    primaryValue: birth.birthSummary,
//                    dictionary: dictionary
//                ),
//                KeyValueModel.dictionaryModel(
//                    title: Localizable.journal_section_previous_births_puerperal_sepsis_summary(),
//                    primaryValue: birth.puerperalSepsis?.description,
//                    dictionary: dictionary
//                )
//            ])
//    }
//    
//    private func mapChild(_ child: PreviousBirthsSectionAllOfChildren, birth: PreviousBirthsSectionAllOfBirths, dictionary: CMSDictionary) -> [KeyValueModel] {
//        [            
//            KeyValueModel.dictionaryModel(
//                title: Localizable.journal_section_previous_births_child_sex(),
//                primaryValue: child.sex?.description,
//                dictionary: dictionary
//            ),
//            
//            KeyValueModel.dictionaryModel(
//                title: Localizable.journal_section_previous_births_child_weight(),
//                primaryValue: child.birthWeight?.valueWithUnit,
//                dictionary: dictionary
//            ),
//            
//            KeyValueModel.dictionaryModel(
//                title: Localizable.journal_section_previous_births_child_outcome(),
//                primaryValue: child.outcome?.description,
//                dictionary: dictionary
//            ),
//            
//            KeyValueModel.dictionaryModel(
//                title: Localizable.journal_section_previous_births_child_current_health(),
//                primaryValue: child.childsCurrentHealthStatus,
//                dictionary: dictionary
//            )
//        ]
//    }
//    
//    private func mapAbortion(_ abortion: PreviousAbortionsSectionAllOfAbortions, dictionary: CMSDictionary?) -> Abortion {
//        Abortion(table: [
//            KeyValueModel.dictionaryModel(
//                title: Localizable.journal_section_previous_abortions_abortion_year(),
//                primaryValue: abortion.year?.description,
//                dictionary: dictionary
//            ),
//            
//            KeyValueModel.dictionaryModel(
//                title: Localizable.journal_section_previous_abortions_abortion_gestation_length(),
//                primaryValue: abortion.gestationLength?.valueWithoutUnit,
//                dictionary: dictionary
//            ),
//            
//            KeyValueModel.dictionaryModel(
//                title: Localizable.journal_section_previous_abortions_abortion_type(),
//                primaryValue: abortion.type?.description,
//                dictionary: dictionary
//            ),
//            
//            KeyValueModel.dictionaryModel(
//                title: Localizable.journal_section_previous_abortions_abortion_indication(),
//                primaryValue: abortion.indication,
//                dictionary: dictionary
//            )
//        ])
//    }
//}
