//// The MIT License
////
//// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
////
//// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
////
//// Permission is hereby granted, free of charge, to any person obtaining a copy of
//// this software and associated documentation files (the "Software"), to deal in
//// the Software without restriction, including without limitation the rights to
//// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
//// of the Software, and to permit persons to whom the Software is furnished to do
//// so, subject to the following conditions:
////
//// The above copyright notice and this permission notice shall be included in all
//// copies or substantial portions of the Software.
////
//// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
//// SOFTWARE.
//
//import Foundation
//import CMSServices
//import ErrorData
//import GMAppData
//import MaternityServices
//import Combine
//import UIData
//
//final class ScreeningsServiceImpl : ScreeningsService {
//    @DI private var maternityEnvironmentStore: MaternityRepository
//    @DI private var dictionaryService: DictionaryService
//
//    func fetchBloodType() -> AnyPublisher<[KeyValueModel], ServiceError> {
//        let screeningsSection = maternityEnvironmentStore.selectedMaternity?.screeningsSection
//
//        return dictionaryService.fetchDictionaryWithEmptyFallback()
//            .map { dictionary -> [KeyValueModel] in
//                [
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_details_bloodtype_taken(),
//                        primaryValue: screeningsSection?.maternalBloodtype?.bloodSampleTaken?.description,
//                        dictionary: dictionary
//                    ),
//
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_details_bloodtype_maternal_rhesus_type(),
//                        primaryValue: screeningsSection?.maternalRhD?.rhesusType?.description,
//                        dictionary: dictionary
//                    ),
//
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_details_bloodtype_irregular_blood_group_antibody_present(),
//                        primaryValue: screeningsSection?.maternalAntibody?.irregularBloodGroupAntibodyPresent?.description,
//                        dictionary: dictionary
//                    ),
//
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_details_bloodtype_fetal_rhesus_type(),
//                        primaryValue: screeningsSection?.fetalRhDAntibody?.rhesusType?.description,
//                        dictionary: dictionary
//                    ),
//
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_details_bloodtype_maternal_rhd_antibody(),
//                        primaryValue: screeningsSection?.hasMaternalAntibodyInWeek25IfRhesusNegative?.description,
//                        dictionary: dictionary
//                    ),
//
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_details_bloodtype_anti_d_immunoglobin_given(),
//                        primaryValue: screeningsSection?.antiDImmunoglobulinGiven?.value?.description,
//                        secondaryValue: JournalDateFormatter.format(date: screeningsSection?.antiDImmunoglobulinGiven?.date),
//                        dictionary: dictionary
//                    )
//                ]
//            }
//            .mapToServiceError()
//            .eraseToAnyPublisher()
//    }
//
//    func fetchDiabetes() -> AnyPublisher<[KeyValueModel], ServiceError> {
//        let screeningsSection = maternityEnvironmentStore.selectedMaternity?.screeningsSection
//
//        return dictionaryService.fetchDictionaryWithEmptyFallback()
//            .map { dictionary -> [KeyValueModel] in
//                [
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_details_diabetes_week_18_to_20(),
//                        primaryValue: screeningsSection?.diabetesWeek18To20?.valueWithUnit,
//                        secondaryValue: JournalDateFormatter.format(date: screeningsSection?.diabetesWeek18To20?.modifiedTime),
//                        dictionary: dictionary
//                    ),
//
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_details_diabetes_week_28_to_30(),
//                        primaryValue: screeningsSection?.diabetesWeek28To30?.valueWithUnit,
//                        secondaryValue: JournalDateFormatter.format(date: screeningsSection?.diabetesWeek28To30?.modifiedTime),
//                        dictionary: dictionary
//                    ),
//
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_details_diabetes_glycorusia(),
//                        primaryValue: screeningsSection?.diabetesGlycosuria?.valueWithUnit,
//                        secondaryValue: JournalDateFormatter.format(date: screeningsSection?.diabetesGlycosuria?.modifiedTime),
//                        dictionary: dictionary
//                    )
//                ]
//            }
//            .mapToServiceError()
//            .eraseToAnyPublisher()
//    }
//
//    func fetchStreptococcusGroupB() -> AnyPublisher<[KeyValueModel], ServiceError> {
//        let screeningsSection = maternityEnvironmentStore.selectedMaternity?.screeningsSection
//
//        return dictionaryService.fetchDictionaryWithEmptyFallback()
//            .map { dictionary -> [KeyValueModel] in
//                [
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_details_streptococcus_group_b_found(),
//                        primaryValue: screeningsSection?.streptococcusValue,
//                        dictionary: dictionary
//                    )
//                ]
//            }
//            .mapToServiceError()
//            .eraseToAnyPublisher()
//    }
//
//    func fetchVitaminD() -> AnyPublisher<[KeyValueModel], ServiceError> {
//        let screeningsSection = maternityEnvironmentStore.selectedMaternity?.screeningsSection
//
//        return dictionaryService.fetchDictionaryWithEmptyFallback()
//            .map { dictionary -> [KeyValueModel] in
//                [
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_details_vitamin_d_measurement(),
//                        primaryValue: screeningsSection?.vitaminDConsumption?.valueWithUnit,
//                        secondaryValue: JournalDateFormatter.format(date: screeningsSection?.vitaminDConsumption?.date),
//                        dictionary: dictionary
//                    )
//                ]
//            }
//            .mapToServiceError()
//            .eraseToAnyPublisher()
//    }
//
//    func fetchOthers() -> AnyPublisher<[KeyValueModel], ServiceError> {
//        let screeningsSection = maternityEnvironmentStore.selectedMaternity?.screeningsSection
//
//        return dictionaryService.fetchDictionaryWithEmptyFallback()
//            .map { dictionary -> [KeyValueModel] in
//                [
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_details_other_screenings_hepatitis_b(),
//                        primaryValue: screeningsSection?.hepatitisB?.result?.description,
//                        secondaryValue: JournalDateFormatter.format(date: screeningsSection?.hepatitisB?.date),
//                        dictionary: dictionary
//                    ),
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_details_other_screenings_hiv(),
//                        primaryValue: screeningsSection?.hiv?.result?.description,
//                        secondaryValue: JournalDateFormatter.format(date: screeningsSection?.hiv?.date),
//                        dictionary: dictionary
//                    ),
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_details_other_screenings_syphilis(),
//                        primaryValue: screeningsSection?.syphilis?.result?.description,
//                        secondaryValue: JournalDateFormatter.format(date: screeningsSection?.syphilis?.date),
//                        dictionary: dictionary
//                    ),
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_details_other_screenings_chlamydia(),
//                        primaryValue: screeningsSection?.chlamydia?.result?.description,
//                        secondaryValue: JournalDateFormatter.format(date: screeningsSection?.chlamydia?.date),
//                        dictionary: dictionary
//                    ),
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_details_other_screenings_gonorrhea(),
//                        primaryValue: screeningsSection?.gonorrhea?.result?.description,
//                        secondaryValue: JournalDateFormatter.format(date: screeningsSection?.gonorrhea?.date),
//                        dictionary: dictionary
//                    ),
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_details_other_screenings_hemoglobinopathy(),
//                        primaryValue: screeningsSection?.hemoglobinopathy?.result?.description,
//                        secondaryValue: JournalDateFormatter.format(date: screeningsSection?.hemoglobinopathy?.date),
//                        dictionary: dictionary
//                    ),
//                    KeyValueModel.dictionaryModel(
//                        title: Localizable.journal_details_other_screenings_mrsa_swap(),
//                        primaryValue: screeningsSection?.mrsaSwap?.value?.description,
//                        secondaryValue: JournalDateFormatter.format(date: screeningsSection?.mrsaSwap?.date),
//                        dictionary: dictionary
//                    )
//                ]
//            }
//            .mapToServiceError()
//            .eraseToAnyPublisher()
//    }
//}
