// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import SharedServices
import DeviceKit
import UIKit

final class SystemInformationServiceImpl: SystemInformationService {
    @DI private var logger: Logger

    var osName: String? {
        Device.current.systemName
    }

    var osVersion: String? {
        Device.current.systemVersion
    }

    var deviceDescription: String {
        Device.current.description
    }

    var appVersion: String? {
        Bundle.main.infoDictionary?["CFBundleShortVersionString"] as? String
    }

    var appBuildVersion: String? {
        Bundle.main.infoDictionary?["CFBundleVersion"] as? String
    }

    var fullSystemInformationString: String {
        "System information: \(osName ?? "N/A") \(osVersion ?? "N/A"), \(deviceDescription), App version: \(appVersion ?? "N/A") (\(appBuildVersion ?? "N/A"))"
    }

    var isSimulator: Bool {
        Device.current.isSimulator
    }

    /// **NOTE TO SELF:** Mock implementation of this always returns true... (spent too long debugging this issue while on mock data 🤦🏻‍♂️)
    var screenHasRoundedCorners: Bool {
        switch Device.current {
        // Fall back for safe area assumption if device is unknown
        case .unknown(let modelName):
            logger.warning("DeviceKit failed to identify the device: \"\(modelName)\". Time to update the DeviceKit dependency?")
            let window = UIApplication.shared.windows.first(where: { $0.isKeyWindow }) ?? UIApplication.shared.windows.first
            return (window?.safeAreaInsets.bottom ?? 0) > 0
        default:
            return Device.current.hasRoundedDisplayCorners
        }
    }
}
