// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import Rswift
import SwiftUI

struct ColorToken {
    let light: Color
    let dark: Color

    func currentColor() -> Color {
        Color(UIColor { traitCollection in
            return traitCollection.userInterfaceStyle == .dark ? UIColor(self.dark) : UIColor(self.light)
        })
    }
    
    func currentUIColor() -> UIColor {
        UIColor { traitCollection in
            return traitCollection.userInterfaceStyle == .dark ? UIColor(self.dark) : UIColor(self.light)
        }
    }
}
class ColorManager {
    // MARK: Background Colors
    static let bgNeutralPrimary = ColorToken(
        light: R.color.grey10.color(),
        dark: R.color.dolphin110.color()
    )
    
    static let bgNeutralSecondary = ColorToken(
        light: Color.white,
        dark: R.color.dolphin120.color()
    )
    
    static let bgSurfaceNeutralPrimary = ColorToken(
        light: Color.white,
        dark: R.color.dolphin100.color()
    )
    
    static let bgSurfaceNeutralSecondary = ColorToken(
        light: R.color.grey10.color(),
        dark: R.color.dolphin110.color()
    )
    
    static let bgSurfaceInteractivePrimary = ColorToken(
        light: R.color.indigo80.color(),
        dark: R.color.indigo70.color()
    )
    
    static let bgSurfaceInteractivePrimaryPressed = ColorToken(
        light: R.color.indigo100.color(),
        dark: R.color.indigo80.color()
    )
    
    static let bgSurfaceInteractivePrimarySubtle = ColorToken(
        light: R.color.violet30.color(),
        dark: R.color.violet40.color()
    )
    
    static let bgSurfaceInteractivePrimarySubtlePressed = ColorToken(
        light: R.color.violet40.color(),
        dark: R.color.violet50.color()
    )
    
    static let bgBlack = ColorToken(
        light: Color.black,
        dark: Color.black
    )
    
    static let bgWhite = ColorToken(
        light: Color.white,
        dark: R.color.dolphin10.color()
    )
    
    static let bgAlert = ColorToken(
        light: R.color.yellow10.color(),
        dark: R.color.yellow10.color()
    )
    
    static let bgError = ColorToken(
        light: R.color.red10.color(),
        dark: R.color.red10.color()
    )
    
    static let bgSuccess = ColorToken(
        light: R.color.green10.color(),
        dark: R.color.green10.color()
    )
    
    // MARK: Text Colors
    static let textPrimary = ColorToken(
        light: R.color.dolphin110.color(),
        dark: R.color.white.color()
    )
    
    static let textSecondary = ColorToken(
        light: R.color.dolphin80.color(),
        dark: R.color.dolphin40.color()
    )
    
    static let textInteractivePrimary = ColorToken(
        light: R.color.indigo80.color(),
        dark: R.color.indigo40.color()
    )
    
    static let textInteractivePrimaryPressed = ColorToken(
        light: R.color.indigo100.color(),
        dark: R.color.indigo50.color()
    )
    
    static let textInteractiveSecondary = ColorToken(
        light: R.color.dolphin110.color(),
        dark: R.color.violet30.color()
    )
    
    static let textInteractiveSecondaryPressed = ColorToken(
        light: R.color.dolphin120.color(),
        dark: R.color.violet20.color()
    )

    static let textDark = ColorToken(
        light: R.color.dolphin110.color(),
        dark: R.color.dolphin110.color()
    )
    
    static let textWhite = ColorToken(
        light: R.color.white.color(),
        dark:  R.color.white.color()
    )
    
    static let textInverted = ColorToken(
        light: R.color.white.color(),
        dark: R.color.dolphin110.color()
    )
    
    static let textBrand = ColorToken(
        light: R.color.indigo80.color(),
        dark: R.color.indigo40.color()
    )
    
    static let textSuccess = ColorToken(
        light: R.color.green80.color(),
        dark: R.color.green80.color()
    )
    
    static let textDanger = ColorToken(
        light: R.color.red70.color(),
        dark: R.color.red70.color()
    )
    
    // Icon Colors
    static let iconPrimary = ColorToken(
        light: R.color.dolphin110.color(),
        dark: R.color.white.color()
    )
    
    static let iconSecondary = ColorToken(
        light: R.color.dolphin80.color(),
        dark: R.color.dolphin40.color()
    )
    
    static let iconInteractivePrimary = ColorToken(
        light: R.color.indigo80.color(),
        dark: R.color.indigo40.color()
    )
    
    static let iconInteractivePrimaryPressed = ColorToken(
        light: R.color.indigo100.color(),
        dark: R.color.indigo50.color()
    )
    
    static let iconInteractivePrimarySubtle = ColorToken(
        light: R.color.violet30.color(),
        dark: R.color.dolphin70.color()
    )
    
    static let iconInteractivePrimarySubtlePressed = ColorToken(
        light: R.color.violet40.color(),
        dark: R.color.dolphin60.color()
    )
    
    static let iconInteractiveSecondary = ColorToken(
        light: R.color.dolphin110.color(),
        dark: R.color.violet30.color()
    )
    
    static let iconInteractiveSecondaryPressed = ColorToken(
        light: R.color.dolphin120.color(),
        dark: R.color.violet20.color()
    )
    
    static let iconDark = ColorToken(
        light: R.color.dolphin110.color(),
        dark: R.color.dolphin110.color()
    )
    
    static let iconInverted = ColorToken(
        light: R.color.white.color(),
        dark: R.color.dolphin110.color()
    )
    
    static let iconInvertedDark = ColorToken(
        light: R.color.black.color(),
        dark: R.color.white.color()
    )
    
    static let iconWhite = ColorToken(
        light: R.color.white.color(),
        dark:  R.color.white.color()
    )
    
    static let iconBlack = ColorToken(
        light: R.color.black.color(),
        dark: R.color.black.color()
    )
    
    static let iconDecorativeMing = ColorToken(
        light: R.color.aqua60.color(),
        dark: R.color.aqua40.color()
    )
    
    static let iconDecorativePurpleHeart = ColorToken(
        light: R.color.indigo80.color(),
        dark: R.color.indigo40.color()
    )
    
    static let iconDecorativeTreePoppy = ColorToken(
        light: R.color.orange50.color(),
        dark: R.color.orange50.color()
    )
    
    static let iconDecorativeBrakBay = ColorToken(
        light: R.color.blue80.color(),
        dark: R.color.blue50.color()
    )
    
    static let iconDecorativePersimmon = ColorToken(
        light: R.color.red50.color(),
        dark: R.color.red50.color()
    )
    
    static let iconDecorativeMartinique = ColorToken(
        light: R.color.dolphin110.color(),
        dark: R.color.dolphin40.color()
    )
    
    static let iconDanger = ColorToken(
        light: R.color.yellow80.color(),
        dark: R.color.yellow80.color()
    )
    
    static let iconError = ColorToken(
        light: R.color.red80.color(),
        dark: R.color.red80.color()
    )
    
    static let iconSuccess = ColorToken(
        light: R.color.green90.color(),
        dark: R.color.green90.color()
    )
    
    static let iconSuccessLight = ColorToken(
        light: R.color.green70.color(),
        dark: R.color.green40.color()
    )
    
    // MARK: Border Colors
    static let borderNeutralPrimary = ColorToken(
        light: R.color.grey30.color(),
        dark: R.color.dolphin90.color()
    )
    
    static let borderInteractivePrimary = ColorToken(
        light: R.color.indigo80.color(),
        dark: R.color.indigo40.color()
    )
    
    static let borderInteractiveSecondary = ColorToken(
        light: R.color.violet50.color(),
        dark: R.color.violet50.color()
    )
    
    static let borderInteractivePrimaryDark = ColorToken(
        light: R.color.indigo100.color(),
        dark: R.color.indigo100.color()
    )
    
    static let borderError = ColorToken(
        light: R.color.yellow30.color(),
        dark: R.color.yellow30.color()
    )
    
    static let borderDanger = ColorToken(
        light: R.color.red30.color(),
        dark: R.color.red30.color()
    )
    
    static let borderSuccess = ColorToken(
        light: R.color.green20.color(),
        dark: R.color.green20.color()
    )
    
    // MARK: Shadow Colors
    static let shadow = ColorToken(
        light: R.color.shadowLight.color(),
        dark: R.color.shadowDark.color()
    )
    
    // MARK: Components
    static let bgBadge = ColorToken(
        light: R.color.violet20.color(),
        dark: R.color.violet20.color()
    )
    
    static let bgInputField = ColorToken(
        light: R.color.dolphin20.color(),
        dark: R.color.dolphin90.color()
    )
    
    static let bgTableCell = ColorToken(
        light: R.color.grey20.color(),
        dark: R.color.dolphin90.color()
    )
    
    static let bgHeaderIcon = ColorToken(
        light: R.color.grey20.color(),
        dark: R.color.dolphin90.color()
    )
    
    static let bgDatePickerSelection = ColorToken(
        light: R.color.black.color().opacity(0.20),
        dark: R.color.white.color().opacity(0.20)
    )
    
    static let borderBadge = ColorToken(
        light: R.color.dolphin50.color(),
        dark: R.color.dolphin80.color()
    )
    
    static let borderChart = ColorToken(
        light: R.color.grey40.color(),
        dark: R.color.grey40.color()
    )
    
    static let tableInteractive = ColorToken(
        light: R.color.indigo80.color(),
        dark: R.color.indigo30.color()
    )
    
    static let shadowTable = ColorToken(
        light: Color("#27294a40"),
        dark: R.color.dolphin120.color()
    )
    
    static let PLOLogo = ColorToken(
        light: Color("#cccccc"),
        dark: R.color.white.color()
    )
    
    static let iconHeaderPurpleHeart = ColorToken(
        light: R.color.indigo80.color(),
        dark: R.color.indigo80.color()
    )
    
    static let iconHeaderTreePoppy = ColorToken(
        light: R.color.orange50.color(),
        dark: R.color.orange50.color()
    )
    
    static let iconHeaderBrakBay = ColorToken(
        light: R.color.blue80.color(),
        dark: R.color.blue80.color()
    )
    
    static let iconHeaderPersimmon = ColorToken(
        light: R.color.red50.color(),
        dark: R.color.red50.color()
    )
    
    static let iconHeaderMartinique = ColorToken(
        light: R.color.dolphin110.color(),
        dark: R.color.dolphin110.color()
    )
    
    static let bottomSheetHandleBar = ColorToken(
        light: R.color.grey30.color(),
        dark: R.color.grey30.color()
    )
    
    // MARK: Developer created
    static let purpleShadow = ColorToken(
        light: R.color.violet80.color().opacity(0.14),
        dark: R.color.violet80.color().opacity(0.14)
    )
}
