// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import GMAppData
import SwiftUI

extension Activity {
    func isPlannedAfterWeek(_ currentWeek: Int) -> Bool {
        untilWeek >= currentWeek
    }
    
    func isPlannedBeforeWeek(_ currentWeek: Int) -> Bool {
        untilWeek < currentWeek
    }
    
    var dotColor: Color {
        switch performer {
        case .doctor:
            return  ColorManager.iconHeaderTreePoppy.currentColor()
        case .hospital:
            return  ColorManager.iconDecorativePurpleHeart.currentColor()
        case .dueDate:
            return ColorManager.iconDecorativeMartinique.currentColor()
        case .heatlhcareProvider:
            return  ColorManager.iconDecorativeMing.currentColor()
        }
    }
}

struct ActivityStatusSet {
    let planned: [Activity]
    let finished: [Activity]

    static func empty() -> ActivityStatusSet {
        ActivityStatusSet(planned: [], finished: [])
    }

    var isEmpty: Bool {
        planned.isEmpty && finished.isEmpty
    }
}

extension Sequence where Element == Activity {
    func statusSetForMaternity(week: Int, dateOfBirth: Date?) -> ActivityStatusSet {
        guard let dateOfBirth = dateOfBirth else { return statusSetForWeek(week) }
        return statusSetAfterBirth()
    }
    
    
    func statusSetForWeek(_ week: Int ) -> ActivityStatusSet {
        let planned = self.filter({ $0.isPlannedAfterWeek(week) })
        let finished = self.filter({ $0.isPlannedBeforeWeek(week) })
        return ActivityStatusSet(
            planned: planned,
            finished: finished
        )
    }
    
    func statusSetAfterBirth() -> ActivityStatusSet {
        let planned = self.filter({ $0.isAfterBirth })
        let finished = self.filter({ !$0.isAfterBirth })
        return ActivityStatusSet(
            planned: planned,
            finished: finished
        )
    }
}
