// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation

extension Checklist {
    var completedItems: UInt {
        UInt(items.filter { $0.isChecked }.count)
    }

    var totalItems: UInt {
        UInt(items.count)
    }

    var progress: Double {
        let pct = Double(completedItems) / Double(totalItems)
        return pct.isNaN ? 0 : pct
    }
}

extension Checklist {
    func itemForId(id: String) -> Checklist.Item? {
        items.first(where: { $0.id == id })
    }

    static func previewList() -> [Checklist] {
        (0..<5).map({ i in
            Checklist(
                id: i,
                title: "Title \(i)",
                description: Bool.random() ? String.loremIpsum(.small) : nil,
                items: Checklist.Item.previewList()
            )
        })
    }
}

extension Checklist.Item {
    static func previewList() -> [Checklist.Item] {
        (0..<5).map({ i in
            Checklist.Item(
                id: "Item-ID-\(i)",
                title: "Title",
                isChecked: Bool.random()
            )
        })
    }
}

extension Sequence where Element == Checklist {
    func itemForId(id: String) -> Checklist.Item? {
        var item: Checklist.Item?
        self.forEach { (checklist) in
            if let i = checklist.itemForId(id: id) {
                item = i
                return
            }
        }
        return item
    }
}
