// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import GMAppData

private let fetusTypePrefix: String = "fetus_"
extension Sequence where Element == Observation {
    var motherObservations: [Observation] {
        self.filter({ $0.type?.rawValue.hasPrefix(fetusTypePrefix) == false })
    }

    var fetusesObservations: [[Observation]] {
        let grouped = self.filter({ $0.type?.rawValue.hasPrefix(fetusTypePrefix) == true })
            .reduce([:]) { (dictionary: [String: [Observation]], observation: Observation) -> [String: [Observation]] in
                var mutableDic = dictionary
                if let fetus = observation.fetus {
                    if mutableDic[fetus] == nil {
                        mutableDic[fetus] = []
                    }
                    mutableDic[fetus]?.append(observation)
                }
                return mutableDic
            }
            .values
        return Array(grouped).sorted(by: { ($0.first?.fetus ?? "") < ($1.first?.fetus ?? "") })
    }

    var latestChange: Observation? {
        self.max(by: \.dateOfMeasurement)
    }
}
