// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import GMAppData
import Foundation

/// Generic implementation of value unit types from API
protocol ValueWithUnit {
    associatedtype NumberType : Numeric
    var optionalUnit: String? { get }
    var optionalValue: NumberType? { get }
    func convertToNsNumber(_ number: NumberType) -> NSNumber
}

private var numberFormatter: NumberFormatter = {
    let nf = NumberFormatter()
    nf.minimumFractionDigits = 0
    nf.maximumFractionDigits = 2
    return nf
}()

extension ValueWithUnit {
    public var valueWithUnit: String {
        guard let value = optionalValue else {
            return Localizable.common_missing_data()
        }
        let valueString: String = numberFormatter.string(from: convertToNsNumber(value)) ?? "\(value)"
        let result: String
        if let unit = optionalUnit {
            result = "\(valueString) \(unit)"
        } else {
            result = valueString
        }
        return result
    }

    public var valueWithoutUnit: String {
        guard let value = optionalValue else {
            return Localizable.common_missing_data()
        }
        let valueString: String = numberFormatter.string(from: convertToNsNumber(value)) ?? "\(value)"
        return "\(valueString)"
    }
}

extension ValueWithUnit where NumberType == Int {
    func convertToNsNumber(_ number: NumberType) -> NSNumber {
        NSNumber(value: number)
    }
}

extension ValueWithUnit where NumberType == Double {
    func convertToNsNumber(_ number: NumberType) -> NSNumber {
        NSNumber(value: number)
    }
}
