// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import TIM
import TIMEncryptedStorage
import AppAuth

private let scopes = [ OIDScopeOpenID ]
private let testIssuerUrl = "https://test.cloud.idm.trifork.com"
private let prodIssuerUrl = "https://oidc.sundhedsdatastyrelsen.dk"
private let realm = "gravid"
private let clientIDMock = "gravidappmock"
private let clientID = "gravidapp"

extension TIMConfiguration {
    static func forBuildConfiguration(_ config: BuildConfiguration) -> TIMConfiguration {
        switch config {
        case .debug, .internalTest, .appStoreReview:
            return TIMConfiguration(
                timBaseUrl: URL(string: testIssuerUrl)!,
                realm: realm,
                clientId: clientIDMock,
                redirectUri: URL(string: "\(clientIDMock):/")!,
                scopes: scopes,
                encryptionMethod: .aesGcm
            )
        case .release:
            return TIMConfiguration(
                timBaseUrl: URL(string: prodIssuerUrl)!,
                realm: realm,
                clientId: clientID,
                redirectUri: URL(string: "\(clientID):/")!,
                scopes: scopes,
                encryptionMethod: .aesGcm
            )
        }
    }
}
