// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct FloatingAnimation: GeometryEffect {
    private let path: Path

    init(radius: CGFloat, pct: CGFloat) {
        self.pct = pct

        // Generate random points along the circle edge
        let numberOfValues = 10
        let randomAngles = (0...numberOfValues).map({ _ in CGFloat.random(in: 0...(CGFloat.pi * 2)) })
        let randomXValues = randomAngles.map { cos($0) * radius }
        let randomYValues = randomAngles.map { sin($0) * radius }

        let points = zip(randomXValues, randomYValues).map({ CGPoint(x: $0, y: $1) })
        var path = Path()
        path.move(to: .zero)
        for point in points {
            path.addLine(to: point)
        }
        self.path = path
    }

    func effectValue(size: CGSize) -> ProjectionTransform {
        let point = percentPoint(pct)
        let transform = CGAffineTransform(
            translationX: point.x,
            y: point.y
        )
        return ProjectionTransform(transform)
    }

    func percentPoint(_ percent: CGFloat) -> CGPoint {
        let pct = percent > 1 ? 0 : (percent < 0 ? 1 : percent)

        let f = pct > 0.999 ? CGFloat(1 - 0.001) : pct
        let t = pct > 0.999 ? CGFloat(1) : pct + 0.001
        let tp = path.trimmedPath(from: f, to: t)

        return CGPoint(x: tp.boundingRect.midX, y: tp.boundingRect.midY)
    }

    var pct: CGFloat = 0.0
    var animatableData: CGFloat {
        get { pct }
        set { pct = newValue }
    }
}
