// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import UIKit
import Logger
import os.log

final class ErrorFlashLogger : LoggerProtocol {

    func log(_ message: String, at level: LogLevel, file: String, function: String, line: UInt, category: String?) {
        let color: UIColor?
        switch level {
        case .warning:
            color = .yellow
        case .error:
            color = .orange
        case .critical:
            color = .red
        default:
            color = nil
        }

        DispatchQueue.main.async {
            if  let color = color,
                let keyWindow = UIApplication.shared.windows.first(where: { $0.isKeyWindow }) {
                let flashView = UIView()
                flashView.backgroundColor = color
                flashView.frame = keyWindow.bounds
                keyWindow.addSubview(flashView)

                UIView.animate(withDuration: 0.2, delay: 0.0, options: .curveEaseIn) {
                    flashView.alpha = 0.0
                } completion: { (_) in
                    flashView.removeFromSuperview()
                }
            }
        }
    }
}
