// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import UIKit
import SwiftUI

final class Appearances {
    static func setup() {
        navigationBar()
        tabBar()
        segmentedControls()
        alertControllers()
        searchBar()
    }

    private static let allStates: [UIControl.State] = [
        .disabled,
        .focused,
        .highlighted,
        .normal,
        .selected,
        .reserved
    ]

    private static func navigationBar() {
        UINavigationBar.appearance().compactAppearance = .default()
        UINavigationBar.appearance().standardAppearance = .default()
        UINavigationBar.appearance().scrollEdgeAppearance = .default()

        UINavigationBar.appearance().barTintColor = R.color.navigationBar()

        UINavigationBar.appearance().tintColor = ColorManager.textPrimary.currentUIColor()
    }

    private static func tabBar() {
        UITabBar.appearance().isTranslucent = false
    }

    private static func segmentedControls() {
        // The only way to style a `Picker` with `SegmentedPickerStyle` at the moment...
        // This should be changed in the future, when Apple hopefully allows another way to do it through SwiftUI
        allStates.forEach { (state: UIControl.State) in
            UISegmentedControl.appearance().setTitleTextAttributes([
                NSAttributedString.Key.font: state == UIControl.State.selected ? FontStyle.textSStrong.scaledUIFont() : FontStyle.textS.scaledUIFont(),
                NSAttributedString.Key.foregroundColor: ColorManager.textPrimary.currentUIColor() as Any
            ], for: state)
        }
    }

    private static func alertControllers() {
        UIView.appearance(whenContainedInInstancesOf: [UIAlertController.self]).tintColor = ColorManager.iconDecorativePurpleHeart.currentUIColor()
    }

    private static func searchBar() {
        UIBarButtonItem.appearance(whenContainedInInstancesOf: [UISearchBar.self])
            .setTitleTextAttributes([
                NSAttributedString.Key.foregroundColor: ColorManager.iconPrimary.currentUIColor() as Any
            ], for: .normal)

        let textFieldFont: UIFont = FontStyle.textM.scaledUIFont()
        UITextField.appearance(whenContainedInInstancesOf: [UISearchBar.self])
            .defaultTextAttributes = [
                NSAttributedString.Key.font: textFieldFont,
                NSAttributedString.Key.foregroundColor: ColorManager.textPrimary.currentUIColor() as Any
            ]

        UITextField.appearance(whenContainedInInstancesOf: [UISearchBar.self])
            .attributedPlaceholder = NSAttributedString(
                string: Localizable.search_hint(),
                attributes: [
                    NSAttributedString.Key.font: textFieldFont,
                    NSAttributedString.Key.foregroundColor: ColorManager.textSecondary.currentUIColor() as Any
            ])

        UITextField.appearance(whenContainedInInstancesOf: [UISearchBar.self])
            .tintColor = ColorManager.iconDecorativePurpleHeart.currentUIColor()

        UITextField.appearance(whenContainedInInstancesOf: [UISearchBar.self])
            .backgroundColor = ColorManager.bgInputField.currentUIColor()

        UISearchBar.appearance()
            .setImage(R.image.icons.basic.search(), for: .search, state: .normal)

        UISearchBar.appearance()
            .setImage(R.image.icons.basic.close(), for: .clear, state: .normal) // might nice sizing?

        UISearchBar.appearance().barTintColor = R.color.navigationBar()
        UISearchBar.appearance().tintColor = ColorManager.textPrimary.currentUIColor()
        UISearchBar.appearance().backgroundImage = UIImage()
        UISearchBar.appearance().backgroundColor = .clear

        UISearchBar.appearance().setSearchFieldBackgroundImage(UIImage(), for: .normal)
    }
}
