// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import UIKit
import SwiftUI

struct FontStyle {
    let font: UIFont
    let textStyle: UIFont.TextStyle
    
    var scaledFontSize: CGFloat {
        UIFontMetrics(forTextStyle: textStyle).scaledValue(for: font.pointSize)
    }
    
    func scaledFont() -> Font {
        Font.custom(
            font.fontName,
            size: scaledFontSize
        )
    }
    
    func scaledUIFont() -> UIFont {
        let fontMetrics: UIFontMetrics
        if textStyle.rawValue.starts(with: "UICT") {
            fontMetrics = UIFontMetrics(forTextStyle: textStyle)
        } else {
            fontMetrics = UIFontMetrics.default
        }
        return fontMetrics.scaledFont(for: font)
        
    }
}

extension FontStyle {

    // MARK: - Custom controls
    static let keyboard = FontStyle(
        font: R.font.titilliumWebLight(size: 25)!,
        textStyle: .callout
    )
    
    // MARK: - Headers
    static let headlineXL = FontStyle(
        font: R.font.ptSansBold(size: 32)!,
        textStyle: .largeTitle
    )
    
    static let headlineL = FontStyle(
        font: R.font.ptSansBold(size: 24)!,
        textStyle: .title1
    )
    
    static let headlineM = FontStyle(
        font: R.font.ptSansBold(size: 20)!,
        textStyle: .title2
    )
    
    static let headlineS = FontStyle(
        font: R.font.ptSansBold(size: 18)!,
        textStyle: .title3
    )
    
    static let headlineXS = FontStyle(
        font: R.font.ptSansBold(size: 16)!,
        textStyle: .headline
    )
    
    static let headlineXXS = FontStyle(
        font: R.font.ptSansBold(size: 12)!,
        textStyle: .subheadline
    )
    
    // MARK: - Text
    static let textXL = FontStyle(
        font: R.font.ptSansRegular(size: 24)!,
        textStyle: .body
    )
    
    static let textXLStrong = FontStyle(
        font: R.font.ptSansBold(size: 24)!,
        textStyle: .body
    )
    
    static let textL = FontStyle(
        font: R.font.ptSansRegular(size: 20)!,
        textStyle: .body
    )
    
    static let textLStrong = FontStyle(
        font: R.font.ptSansBold(size: 20)!,
        textStyle: .body
    )
    
    static let textM = FontStyle(
        font: R.font.ptSansRegular(size: 16)!,
        textStyle: .body
    )
    
    static let textMStrong = FontStyle(
        font: R.font.ptSansBold(size: 16)!,
        textStyle: .body
    )
    
    static let textS = FontStyle(
        font: R.font.ptSansRegular(size: 14)!,
        textStyle: .body
    )
    
    static let textSStrong = FontStyle(
        font: R.font.ptSansBold(size: 14)!,
        textStyle: .body
    )
    
    static let textXS = FontStyle(
        font: R.font.ptSansRegular(size: 12)!,
        textStyle: .body
    )
    
    static let textXSStrong = FontStyle(
        font: R.font.ptSansBold(size: 12)!,
        textStyle: .body
    )
    
    static let textXXS = FontStyle(
        font: R.font.ptSansRegular(size: 10)!,
        textStyle: .body
    )
    
    static let textXXSStrong = FontStyle(
        font: R.font.ptSansBold(size: 10)!,
        textStyle: .body
    )
    
    // MARK: - Buttons
    static let buttonL = FontStyle(
        font: R.font.ptSansBold(size: 16)!,
        textStyle: .body
    )
    
    static let buttonM = FontStyle(
        font: R.font.ptSansBold(size: 14)!,
        textStyle: .body
    )
    
    static let buttonS = FontStyle(
        font: R.font.ptSansBold(size: 12)!,
        textStyle: .body
    )
}
