// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import Combine
import ErrorData
import GMAppData

protocol UserContextProtocol {

    /// Indicates whether the user has handled the onboarding flow (either logged in or skipped it)
    var hasHandledOnboardingFlow: Bool { get }

    /// Indicates whether the user has enabled authenticataion on the app
    var hasEnabledLocalAuthentication: Bool { get }
    
    var isLocalAuthenticated: Bool { get }
    
    /// Returns `true` if TIM has any user registered in the storage, otherwise `false`
    var hasUserRegistered: Bool { get }

    /// Indicates how many times the swipe to delete tip has been shown
    var swipeToDeleteTipCount: Int { get }

    /// Removes all data stored for the user.
    /// This will present the onboarding flow immediately after the cleanup
    func resetAllUserData()

    /// Sets the `hasHandledOnboardingFlow` property.
    /// The value is persisted.
    func setHasHandledOnboardingFlow(_ handled: Bool)
    
    /// Sets the `hasEnabledAuthentication` property.
    /// The value is persisted.
    func sethasEnabledAuthentication(_ enabled: Bool)
    
    func setIsAuthenticated(_ authenticated: Bool)

    /// Resets user stored settings, such that a new user won't share saved data with previous users from same device.
    func clearStoredUserSettings()
    
    /// Resets the checklist and the stored maternity on device
    func clearEnvironmentStoreStates()
    
    /// increments the count for times we have shown the tip
    func incrementSwipeToDeleteTipCount()
    
    /// sets the count to max amout the disable it
    func disableSwipeToDeleteTip()
}
