// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

enum BadgeStyle {
    case neutral
    case branded
    
    var backgroundColor: Color {
        switch self {
        case .neutral:
            return ColorManager.bgSurfaceNeutralSecondary.currentColor()
        case .branded:
            return ColorManager.bgBadge.currentColor()
        }
    }
    
    var borderColor: Color {
        switch self {
        case .neutral:
            return ColorManager.borderBadge.currentColor()
        case .branded:
            return ColorManager.borderInteractiveSecondary.currentColor()
        }
    }
    
    var textColor: Color {
        switch self {
        case .neutral:
            return ColorManager.textSecondary.currentColor()
        case .branded:
            return ColorManager.textBrand.currentColor()
        }
    }
}

struct Badge: View {
    let title: String
    let style: BadgeStyle
    
    init(title: String, style: BadgeStyle = .neutral) {
        self.title = title
        self.style = style
    }
    
    var body: some View {
        BaseCardView(
            cornerRadius: Metrics.Radius.radius8,
            backgroundColor: style.backgroundColor,
            borderColor: style.borderColor) {
                Text(title)
                    .applyTextStyle(fontStyle: FontStyle.buttonM, textColor: style.textColor)
                    .padding(.horizontal, Metrics.Spacing.space12)
                    .padding(.vertical, Metrics.Spacing.space4)
            }
    }
}

#Preview {
    VStack(spacing: 8) {
        Badge(title: "badge", style: .branded)
        Badge(title: "badge", style: .neutral)
    }
}
