// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import UIKit
import SwiftUI

struct BaseButton: View {
    @Environment(\.isEnabled) private var isEnabled: Bool
    
    let title: String?
    let leftIcon: String?
    let rightIcon: String?
    let foregroundColor: Color
    let borderColor: Color
    let action: () -> Void
    
    init(
        title: String? = nil,
        leftIcon: String? = nil,
        rightIcon: String? = nil,
        foregroundColor: Color = ColorManager.textPrimary.currentColor(),
        borderColor: Color = .clear,
        action: @escaping () -> Void
    ) {
        self.title = title
        self.leftIcon = leftIcon
        self.rightIcon = rightIcon
        self.foregroundColor = foregroundColor
        self.borderColor = borderColor
        self.action = action
    }
    
    var body: some View {
        Button(action: action, label: {
            HStack {
                if let leftIcon = leftIcon {
                    Image(leftIcon)
                        .resizable()
                        .renderingMode(.template)
                        .mediumIconStyle()
                }
                
                if let title = title {
                    Text(title)
                       // .applyTextStyle(fontStyle: FontStyle.buttonL)
                        .multilineTextAlignment(.center)
                }
                
                if let rightIcon = rightIcon {
                    Image(rightIcon)
                        .resizable()
                        .renderingMode(.template)
                        .mediumIconStyle()
                }
            }
            .frame(maxWidth: .infinity)
            .padding(Metrics.Spacing.space16)
            .cornerRadius(Metrics.Radius.radius8)
            .overlay(
                RoundedRectangle(cornerRadius: Metrics.Radius.radius8)
                    .stroke(borderColor, lineWidth: 1.5)
            )
        })
       // .foregroundStyle(.pink)
    }
}

struct BaseButton_Previews: PreviewProvider {
    static var previews: some View {
        ZStack {
            Color.gray
            VStack(spacing: 20) {
                BaseButton(
                    title: "Button",
                    leftIcon: R.image.icons.basic.arrowLeft.name,
                    rightIcon: R.image.icons.basic.arrowRight.name,
                    borderColor: .red,
                    action: { }
                )
                BaseButton(
                    title: (0...15).map({ _ in "test "}).joined(),
                    rightIcon: "arrow.right",
                    foregroundColor: .pink,
                    action: { }
                )
                BaseButton(
                    title: "Hello im disabled!",
                    leftIcon: R.image.icons.basic.arrowLeft.name,
                    action: { }
                )
                .disabled(true)
            }
            .padding()
        }
        .ignoresSafeArea()
        
    }
}
