// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct BaseButtonStyle: ButtonStyle {
    let isEnabled: Bool
    let normalTextColor: Color
    let pressedTextColor: Color
    let normalColor: Color
    let pressedColor: Color
    let normalBorderColor: Color
    let pressedBorderColor: Color
    
    init(
        isEnabled: Bool,
        normalTextColor: Color,
        pressedTextColor: Color,
        normalColor: Color,
        pressedColor: Color,
        normalBorderColor: Color = .clear,
        pressedBorderColor: Color = .clear
    ) {
        self.isEnabled = isEnabled
        self.normalTextColor = normalTextColor
        self.pressedTextColor = pressedTextColor
        self.normalColor = normalColor
        self.pressedColor = pressedColor
        self.normalBorderColor = normalBorderColor
        self.pressedBorderColor = pressedBorderColor
    }
    
    func makeBody(configuration: Self.Configuration) -> some View {
        configuration.label
            .font(FontStyle.buttonL.scaledFont())
            .foregroundStyle(configuration.isPressed ? pressedTextColor : normalTextColor)
            .background(configuration.isPressed ? pressedColor : normalColor)
            .cornerRadius(Metrics.Radius.radius8)
            .overlay(
                RoundedRectangle(cornerRadius: Metrics.Radius.radius8)
                    .stroke(configuration.isPressed ? pressedBorderColor : normalBorderColor, lineWidth: 1.5)
            )
            .opacity(isEnabled ? 1.0 : 0.5)
    }
}
