// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import UIKit
import SwiftUI

struct ButtonPrimary: View {
    @Environment(\.isEnabled) private var isEnabled: Bool
    
    let title: String
    let leftIcon: String?
    let rightIcon: String?
    let action: () -> Void
    
    init(
        title: String,
        leftIcon: String? = nil,
        rightIcon: String? = nil,
        action: @escaping () -> Void
    ) {
        self.title = title
        self.leftIcon = leftIcon
        self.rightIcon = rightIcon
        self.action = action
    }
    
    var body: some View {
        BaseButton(
            title: title,
            leftIcon: leftIcon,
            rightIcon: rightIcon,
            action: action
        )
            .buttonStyle(ButtonPrimaryStyle(isEnabled: isEnabled))
    }
}

struct ButtonPrimaryStyle: ButtonStyle {
    let isEnabled: Bool
    
    func makeBody(configuration: Self.Configuration) -> some View {
        BaseButtonStyle(
            isEnabled: isEnabled,
            normalTextColor: ColorManager.textWhite.currentColor(),
            pressedTextColor: ColorManager.textWhite.currentColor(),
            normalColor: ColorManager.bgSurfaceInteractivePrimary.currentColor(),
            pressedColor: ColorManager.bgSurfaceInteractivePrimaryPressed.currentColor()
        )
        .makeBody(configuration: configuration)
    }
}

struct ButtonPrimary_Previews: PreviewProvider {
    static var previews: some View {
        VStack(spacing: 16) {
            ButtonPrimary(
                title: "TestTestTest TestTestTest TestTestTest TestTestTest",
                action: { }
            )
            ButtonPrimary(
                title: "Button",
                rightIcon: R.image.icons.basic.arrowRight.name,
                action: { }
            )
            ButtonPrimary(
                title: "Button",
                rightIcon: R.image.icons.basic.arrowRight.name,
                action: { }
            )
            .disabled(true)
        }
        .padding()
        
    }
}
