// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct SelectionCardView: View {
    let title: String
    let badgeText: String?
    
    @State private var isSelected = false
    
    init(title: String, badgeText: String? = nil) {
        self.title = title
        self.badgeText = badgeText
    }
    
    var body: some View {
        BaseCardView {
            HStack {
                VStack(alignment: .leading, spacing: Metrics.Spacing.space12) {
                    Text(title)
                        .applyTextStyle(fontStyle: .headlineXS)
                    if let badgeText = badgeText {
                        Badge(title: badgeText, style: .branded)
                    }
                }
                Spacer()
                RadioButton(isSelected: $isSelected)
            }
            .padding()
        }
        .onTapGesture {
            withAnimation {
                isSelected.toggle()
            }
        }
    }
}

#Preview {
    ZStack {
        Color.gray
        VStack {
            SelectionCardView(title: "Card title", badgeText: "Badge text")
            SelectionCardView(title: "Card title")
        }
        .padding()
    }
    .ignoresSafeArea()
}
