// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct PageControl: View {
    let numberOfPages: Int
    let currentIndex: Int

    let primaryColor = ColorManager.iconInteractivePrimary.currentColor()
    let secondaryColor = ColorManager.iconInteractivePrimarySubtle.currentColor()

    private let circleSize: CGFloat = 8
    private let circleSpacing: CGFloat = 8

    var body: some View {
        HStack(spacing: circleSpacing) {
            ForEach(0 ..< numberOfPages, id: \.self) { index in
                Circle()
                    .fill(index == currentIndex ? primaryColor : secondaryColor)
                    .frame(width: circleSize, height: circleSize)
                    .tag(index)
            }
        }
    }
}

struct PageIndicators_Previews: PreviewProvider {
    static var previews: some View {
        PageControl(numberOfPages: 5, currentIndex: 2)
    }
}
