// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct Checkbox: View {
    @Binding var isChecked: Bool

    var body: some View {
        Button(action: {
            isChecked.toggle()
        }, label: {
            ZStack {
                Circle()
                    .stroke(ColorManager.iconInteractivePrimary.currentColor(), lineWidth: 2)
                    .background(
                        Circle()
                            .foregroundColor(isChecked ? ColorManager.iconInteractivePrimary.currentColor() : .clear)
                    )
                if isChecked {
                    Image(R.image.icons.basic.check.name)
                        .resizable()
                        .renderingMode(.template)
                        .foregroundColor(ColorManager.iconWhite.currentColor())
                        .mediumIconStyle()
                }
            }
            .accessibility(label: Text(
                isChecked ?
                    Localizable.checklist_item_selected_accessibility_label()
                    : Localizable.checklist_item_unselected_accessibility_label()
            ))
        })
        .frame(
            width: Metrics.Sizes.checkmarkSize,
            height: Metrics.Sizes.checkmarkSize
        )
    }
}

struct Checkbox_Previews: PreviewProvider {
    static var previews: some View {
        VStack {
            Checkbox(isChecked: .constant(false))
            Checkbox(isChecked: .constant(true))
        }
    }
}
