// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct JournalView: View, ScreenTrackable {
    @State var didAppear: Bool = false
    @EnvironmentObject private var maternityStore: MaternityRepositoryImpl

    var body: some View {
        NavigationView {
            VStack(spacing: 0) {
                ScrollView {
                    VStack(spacing: 16) {
                        Group {
                            generateNavigationLink(
                                title: Localizable.journal_section_measurements_title(),
                                description: Localizable.journal_section_measurements_description(),
                                image: Image(R.image.icons.journal.measurements.name),
                                destination: EmptyView())

                            generateNavigationLink(
                                title: Localizable.journal_section_scans_title(),
                                description: Localizable.journal_section_scans_description(),
                                image: Image(R.image.icons.journal.scans.name),
                                destination: EmptyView())

                            generateNavigationLink(
                                title: Localizable.journal_section_screenings_title(),
                                description: Localizable.journal_section_screenings_description(),
                                image: Image(R.image.icons.journal.screenings.name),
                                destination: EmptyView())

                            generateNavigationLink(
                                title: Localizable.journal_section_journal_notes_title(),
                                description: Localizable.journal_section_journal_notes_description(),
                                image: Image(R.image.icons.journal.notes.name),
                                destination: EmptyView())

                            generateNavigationLink(
                                title: Localizable.journal_section_around_the_pregnancy_title(),
                                description: Localizable.journal_section_around_the_pregnancy_description(),
                                image: Image(R.image.icons.journal.around_the_pregnancy.name),
                                destination: EmptyView())

                            generateNavigationLink(
                                title: Localizable.journal_section_overall_assessment_title(),
                                description: Localizable.journal_section_overall_assessment_description(),
                                image: Image(R.image.icons.journal.overall_assesment.name),
                                destination: EmptyView())

                            generateNavigationLink(
                                title: Localizable.journal_section_health_care_title(),
                                description: Localizable.journal_section_health_care_description(),
                                image: Image(R.image.icons.journal.birth_place.name),
                                destination: EmptyView())

                            generateNavigationLink(
                                title: Localizable.journal_section_personal_data_title(),
                                description: Localizable.journal_section_personal_data_description(),
                                image: Image(R.image.icons.journal.personal_information.name),
                                destination: EmptyView())
                        }
                        .padding(.horizontal)
                        BottomScrollIllustration(image: R.image.illustrations.bottom_journal)
                    }
                    .padding(.vertical)
                }
                PregnancyInfoDisclaimerView(text: Localizable.journal_bottom_info_text())
            }
            .navigationBarTitle(Localizable.bottom_navigation_title_journal())
            .screenTracking(screenTrackingName)
        }
        .navigationViewStyle(StackNavigationViewStyle())
    }

    func generateNavigationLink<Destination: View>(title: String, description: String, image: Image, destination: Destination) -> some View {
        NavigationLink(
            destination: destination,
            label: {
                JournalSectionCardView(
                    title: title,
                    description: description,
                    image: image
                )
            })
    }
}

struct JournalView_Previews: PreviewProvider {
    static var previews: some View {
        JournalView()
    }
}

