// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import GMAppData

struct ActivitiesTimeline: View {
    let entryPrefix: String
    let activities: [Activity]
    let backgroundColor: Color
    let dotOpacity: Double

    var body: some View {
        VStack(spacing: Metrics.Spacing.space0) {
            ForEach(activities) { activity in
                let index: Int? = activities.firstIndex(where: { $0 == activity })
                let hideLastLine = index == activities.indices.last && entryPrefix == "planned"
                
                if index == activities.indices.last && entryPrefix == "planned" {
                    ZStack(alignment: .top) {
                        BottomScrollIllustration(image: R.image.illustrations.bottomAppointments)
                            .scaledToFit()
                            
                            .background(.clear)
                            ActivityTimelineEntryView(
                                dotColor: activity.dotColor.opacity(dotOpacity),
                                hideLastLine: true,
                                content: {
                                    ActivityEntryCardView(
                                        activity: activity
                                    )
                                }
                            )
                 
                    }
                } else {
                    ActivityTimelineEntryView(
                        dotColor: activity.dotColor.opacity(dotOpacity),
                        hideLastLine: hideLastLine,
                        content: {
                            ActivityEntryCardView(
                                activity: activity
                            )
                        }
                    )
                    .id("\(entryPrefix)_\(activity.description)")
                }
            }
        }
        .background(backgroundColor)
    }
}
    
#if DEBUG
    struct ActivitiesTimeline_Previews: PreviewProvider {
        static var previews: some View {
            ScrollView {
                VStack(spacing: Metrics.Spacing.space0) {
                    ActivitiesTimeline(
                        entryPrefix: "1",
                        activities: [loadPreviewCarePlan().activities!.first!],
                        backgroundColor: .gray,
                        dotOpacity: 1
                    )
                    ActivitiesTimeline(
                        entryPrefix: "2",
                        activities: loadPreviewCarePlan().activities!,
                        backgroundColor: .white,
                        dotOpacity: 0.4
                    )
                }
            }
        }
    }
#endif
