// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct JournalView: View, ScreenTrackable {
    @State var didAppear: Bool = false
    @EnvironmentObject private var maternityRepo: MaternityRepositoryImpl // We need a vm so we can parse the date of birth to the disclaimer view

    var body: some View {
        NavigationView {
            VStack(spacing: 0) {
                ScrollView {
                    CompatibleVStack(spacing: 16) {
                        Group {
                            generateNavigationLink(
                                title: "Mine målinger",
                                description: "Her kan du følge med i dine løbende oplysninger om bl.a. mors blodtryk, fosterhjertelyd og -aktivitet.",
                                image: Image(R.image.icons.journal.measurement.name),
                                destination: JournalMeasurementsView())

                            generateNavigationLink(
                                title: "Mine scanninger",
                                description: "Her kan du følge med i dine løbende oplysninger om bl.a. ultralydscanninger.",
                                image: Image(R.image.icons.journal.scans.name),
                                destination: JournalMeasurementsView())

                            generateNavigationLink(
                                title: "Mine sundhedsfaglige kontakter",
                                description: "Her kan du finde oplysninger om bl.a. fødested, jordemodercenter og sundhedsplejen.",
                                image: Image(R.image.icons.journal.birthPlace.name),
                                destination: JournalMeasurementsView())

                            generateNavigationLink(
                                title: "Tidligere konsultationer",
                                description: "Her kan du se dine afholdte konsultationer og bl.a. notater, data og målinger fra disse.",
                                image: Image(R.image.icons.journal.personalInformation.name),
                                destination: JournalMeasurementsView())
                        }
                        .padding(.horizontal)
                        BottomScrollIllustration(image: R.image.illustrations.bottomJournal)
                    }
                    .padding(.vertical)
                }
            }
            .navigationBarTitle(Localizable.bottom_navigation_title_journal())
            .screenTracking(screenTrackingName)
        }
        .navigationViewStyle(StackNavigationViewStyle())
    }

    func generateNavigationLink<Destination: View>(title: String, description: String, image: Image, destination: Destination) -> some View {
        NavigationLink(
            destination: destination,
            label: {
                JournalSectionCardView(
                    title: title,
                    description: description,
                    image: image
                )
            })
    }
}

struct JournalView_Previews: PreviewProvider {
    static var previews: some View {
        JournalView()
    }
}
