// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import MaternityServices
import UIData
import Combine
import ErrorData

extension JournalMeasurementsView {
    class ViewModel: ObservableObject, JournalTableContainerViewModel {
        @Published var chartValues: [ChartValue] = []
        @Published var chartNormalValues = ChartNormalValues(upper: [], middle: [], lower: [])
        @Published var chartXData = AxisData(unit: "", values: [])
        @Published var chartYData = AxisData(unit: "", values: [])
        @Published var state: DataLoadingState = .initial
        @Published var bodyMeasureValues: [KeyValueModel] = []

        @Published var titleColumn: DataTableColumn = DataTableColumn(width: 0, cells: [])
        @Published var valueColumns: [DataTableColumn] = []
        @Published var shouldNavigateToActivity: Bool = false
        var activityIdForNavigation: String?

//        @DI private var observationTableService: ObservationTableService
//        @DI private var bodyMeasureService: BodyMeasureService
        @DI private var maternityRepo: MaternityRepository
        
        private var cancelBag = CancelBag()

        func fetchData(force: Bool = false, onRefreshComplete: @escaping RefreshComplete = { }) {
            chartValues = ChartValue.mocklist()
            chartNormalValues = ChartNormalValues.mock()
            chartXData = AxisData.mockXAxis()
            chartYData = AxisData.mockYAxis()
            state = .data
            bodyMeasureValues = [KeyValueModel(title: "Preview", primaryValue: "Test")]
            valueColumns = ScrollableDataTable.previewColumns()
            titleColumn = ScrollableDataTable.previewTitleColumn()
        }
    }

    class PreviewViewModel: ViewModel {
        override func fetchData(force: Bool = false, onRefreshComplete: @escaping RefreshComplete = { }) {
            chartValues = ChartValue.mocklist()
            chartNormalValues = ChartNormalValues.mock()
            chartXData = AxisData.mockXAxis()
            chartYData = AxisData.mockYAxis()
            state = .data
            bodyMeasureValues = [KeyValueModel(title: "Preview", primaryValue: "Test")]
            valueColumns = ScrollableDataTable.previewColumns()
            titleColumn = ScrollableDataTable.previewTitleColumn()
        }
    }
}
