// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct JournalMeasurementChartsCard: View {
    let chartValues: [ChartValue]
    let chartNormalValues: ChartNormalValues
    let chartXData: AxisData
    let chartYData: AxisData
    
    var body: some View {
        BaseCardView {
            if chartValues.isEmpty {
                GeometryReader { geo in
                    EmptyStateView(
                        title: Localizable.journal_section_measurements_graph_no_data_title(),
                        text: Localizable.journal_section_measurements_graph_no_data_description()
                    )
                    .padding([.top, .horizontal])
                    .frame(width: geo.size.width)
                }
            } else {
                MeasurementsChart(
                    chartValues: chartValues,
                    chartNormalValues: chartNormalValues,
                    chartXData: chartXData,
                    chartYData: chartYData
                )
                    .padding()
            }
        }
        .aspectRatio(1, contentMode: .fit)
    }
    
    struct JournalMeasurementChartsCard_Previews: PreviewProvider {
        static var previews: some View {
            JournalMeasurementChartsCard(
                chartValues: ChartValue.mocklist(),
                chartNormalValues: ChartNormalValues.mock(),
                chartXData: AxisData.mockXAxis(),
                chartYData: AxisData.mockYAxis()
            )
        }
    }
}
