// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import UIData
import MaternityServices

extension JournalOverallAssessmentView {
    final class ViewModel: ObservableObject {
        @Published private(set) var overallAssessments: [KeyValueModel] = []
        @Published private(set) var state: DataLoadingState = .initial

        private var cancelBag = CancelBag()

        @DI private var overallAssessmentService: OverallAssessmentService

        init() { }

        func fetchData() {
            state = .loading

            overallAssessmentService.fetchOverallAssessments()
                .receiveOnMain()
                .sink { [weak self] completion in
                    switch completion {
                    case .failure(let error):
                        self?.state = .error(error)
                    default: break
                    }
                } receiveValue: { [weak self] overallAssessments in
                    if overallAssessments.isEmpty {
                        self?.state = .empty(Localizable.journal_section_overall_assessment_empty_title(), Localizable.journal_section_overall_assessment_empty_message())
                    } else {
                        self?.overallAssessments = overallAssessments
                        self?.state = .data
                    }
                }
                .store(in: &cancelBag)
        }
    }
}
