// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct JournalScansView: View, ScreenTrackable {

    @ObservedObject private var viewModel: ViewModel

    init(viewModel: ViewModel = ViewModel()) {
        self.viewModel = viewModel
    }

    var body: some View {
        DataLoadingView(
            state: viewModel.state,
            retryAction: { viewModel.fetchData() },
            content: {
                GeometryReader { geo in
                    RefreshableScrollView {
                        viewModel.fetchData(force: true, onRefreshComplete: $0)
                    } content: {
                        VStack(spacing: 24) {
                            CircleImageHeaderView(
                                title: Localizable.journal_section_scans_title(),
                                text: Localizable.journal_section_scans_description(),
                                imageUrl: nil,
                                image: Image(R.image.icons.journal.scans.name)
                            )
                            .padding([.horizontal, .top])
                            JournalMeasurementsTableCard(
                                tableTitle: Localizable.journal_section_scans_table_title(),
                                valueColumns: viewModel.valueColumns,
                                titleColumn: viewModel.titleColumn,
                                tableWidth: geo.size.width
                            )
                            JournalKeyValueStackView(
                                title: Localizable.journal_section_scans_other_results_title(),
                                data: viewModel.otherResults
                            )
                            .padding()
                        }
                    }
                }
                // Ideally this should be protected by some kind of let-guard to unwrap the optional value, but the NavigationLink fails to animate correctly, when acting as a conditional view.
                viewModel.navigationLink(
                    activityId: viewModel.activityIdForNavigation ?? "",
                    shouldNavigate: $viewModel.shouldNavigateToActivity
                )
            })
            .navigationBarTitle(Text(Localizable.journal_section_scans_title()), displayMode: .inline)
            .protectedAppearanceEvents(onAppear: { viewModel.fetchData() })
            .screenTracking(screenTrackingName)
    }
}

struct JournalScansView_Previews: PreviewProvider {
    static var previews: some View {
        JournalScansView(
            viewModel: JournalScansView.PreviewViewModel()
        )
    }
}
