// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import UIData

struct JournalKeyValueStackView: View, DictionaryPresenter {
    let title: String?
    let data: [KeyValueModel]

    var body: some View {
        CompatibleVStack(alignment: .leading) {
            if let title = title {
                HStack {
                    Text(title)
                        .applyTextStyle(fontStyle: .headlineM)
                    Spacer()
                }
            }
            if data.isEmpty {
                HStack {
                    Spacer()
                    EmptyStateView(
                        title: Localizable.journal_section_health_empty_title(),
                        text: nil
                    )
                    Spacer()
                }
            } else {
                ForEach(data) { item in
                    KeyValueView(
                        title: item.title,
                        primaryValue: item.primaryValue,
                        secondaryValue: item.secondaryValue,
                        dictionaryAction: item.dictionaryValue == nil ? nil : {
                            showDictionaryView(
                                title: item.title,
                                text: item.dictionaryValue ?? Localizable.common_missing_data()
                            )
                        }
                    )
                    .padding(.top)
                }
            }
        }
    }
}

struct JournalKeyValueStackView_Previews: PreviewProvider {
    static var previews: some View {
        JournalKeyValueStackView(
            title: "Overskrift",
            data: [
            KeyValueModel(title: "Personnummer", primaryValue: "111111-1111", secondaryValue: nil, dictionaryValue: nil),
            KeyValueModel(title: "Navn", primaryValue: "111111-1111", secondaryValue: nil, dictionaryValue: nil),
            KeyValueModel(title: "Adresse", primaryValue: "111111-1111", secondaryValue: nil, dictionaryValue: nil),
            KeyValueModel(title: "Postnummer", primaryValue: "111111-1111", secondaryValue: nil, dictionaryValue: nil),
            KeyValueModel(title: "Mobil nr.", primaryValue: "111111-1111", secondaryValue: nil, dictionaryValue: nil)
        ])
    }
}
