// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import GMAppData

struct JournalMeasurementsTableCard: View {

    // Just here to make the view redraw on orientation change, property not used.
    @Environment(\.verticalSizeClass) var verticalSizeClass

    let tableTitle: String
    let valueColumns: [DataTableColumn]
    let titleColumn: DataTableColumn
    let tableWidth: CGFloat

    private let tablePresenter = JournalFullscreenTablePresenter.shared

    var body: some View {
        BottomContainerCardView {
            VStack(spacing: 0) {
                VStack(alignment: .leading, spacing: 8) {
                    Text(tableTitle)
                        .applyTextStyle(fontStyle: .headlineM)
                    Text(Localizable.journal_section_measurements_table_description())
                        .applyTextStyle(fontStyle: .textM)
                        .fixedSize(horizontal: false, vertical: true)
                    HStack {
                        Spacer()
                        Button(
                            action: {
                                tablePresenter.present(
                                    titleColumn: titleColumn,
                                    valueColumns: valueColumns
                                )
                            },
                            label: {
                                HStack {
                                    Text(Localizable.journal_section_measurements_table_rotate())
                                        .applyTextStyle(
                                            fontStyle: .headlineXXS,
                                            textColor: ColorManager.textInteractivePrimary.currentColor()
                                        )
                                    Image(R.image.icons.basic.rotatePhone.name)
                                        .renderingMode(.original)
                                }
                            })
                    }
                    .hidden(valueColumns.isEmpty)
                }
                .padding([.horizontal, .bottom ])
                if valueColumns.isEmpty {
                    EmptyStateView(
                        title: Localizable.journal_section_measurements_graph_no_data_title(),
                        text: Localizable.journal_section_measurements_graph_no_data_description()
                    )
                    .padding([ .horizontal, .bottom ])
                } else {
                    JournalMeasurementScrollableTable(
                        valueColumns: valueColumns,
                        titleColumn: titleColumn,
                        tableWidth: tableWidth,
                        isFullScreen: false
                    )
                }
            }
        }
        .modifier(
            JournalFullscreenTableAutoPresenterViewModifier(
                titleColumn: titleColumn,
                valueColumns: valueColumns,
                presenter: tablePresenter
            )
        )
    }
}

struct JournalMeasurementsTableCard_Previews: PreviewProvider {
    static var previews: some View {
        GeometryReader { geo in
            ScrollView {
                JournalMeasurementsTableCard(
                    tableTitle: "Titel",
                    valueColumns: ScrollableDataTable.previewColumns(),
                    titleColumn: ScrollableDataTable.previewTitleColumn(),
                    tableWidth: geo.size.width
                )
            }
        }
    }
}
