// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import Combine

struct ChecklistAddItemRow: View {
    @State private var title = ""
    @State private var isChecked = false
    @FocusState private var isFocused: Bool
    
    var addItemEvent: (Checklist.Item) -> Void
    
    var body: some View {
        BaseCardView {
            HStack(spacing: Metrics.Spacing.space0) {
                VStack(alignment: .leading) {
                    HStack {
                        Checkbox(
                            isChecked: Binding(
                                get: { isChecked },
                                set: { _ in isChecked.toggle() }
                            )
                        )
                        TextField("",
                                  text: $title)
                        .applyTextFieldStyle(
                            fontStyle: .textM,
                            textColor: ColorManager.textPrimary.currentColor()
                        )
                        .onSubmit {
                            let item = Checklist.Item(id: UUID().uuidString, title: title, isChecked: isChecked)
                            addItemEvent(item)
                        }
                        .focused($isFocused)
                        .onAppear {
                            isFocused = true
                        }
                        .onReceive(Just(title), perform: { _ in
                            limitTextLength(to: 80)
                        })
                        .padding([.leading])
                        Spacer()
                    }
                }.padding()
            }
        }
    }
    
    func limitTextLength(to max: Int) {
        if title.count > max {
            title = String(title.prefix(max))
        }
    }
}
