// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct ChecklistDetailView: View, ScreenTrackable {
    @StateObject private var viewModel: ChecklistDetailViewModel
    
    init(checklist: Checklist) {
        _viewModel = StateObject(wrappedValue: ChecklistDetailViewModel(checklist: checklist))
    }
    
    var body: some View {
        VStack(spacing: .zero) {
            ScrollView {
                withAnimation(.easeOut) {
                    VStack {
                        ChecklistDetailTopView(
                            title: viewModel.checklist.title,
                            infoText: viewModel.checklist.description,
                            progress: viewModel.checklist.progress,
                            completedItems: viewModel.checklist.completedItems,
                            numberOfItems: viewModel.checklist.totalItems
                        )
                        .onTapGesture {
                            UIApplication.shared.sendAction(#selector(UIResponder.resignFirstResponder), to:nil, from:nil, for:nil)
                        }
                        .padding()
                        ChecklistDetailItemList(
                            showSwipeToDeleteTip: $viewModel.swipeToDeleteTipCount,
                            isEditing: $viewModel.isEditing,
                            checklist: viewModel.checklist,
                            toggleItemEvent: { (item: Checklist.Item) in
                                viewModel.alertError = viewModel.toggleCheckItem(item)
                            },
                            deleteItemEvent: { (item: Checklist.Item) in
                                viewModel.alertError = viewModel.deleteCheckItem(item)
                            },
                            addItemEvent: { (item: Checklist.Item) in
                                viewModel.alertError = viewModel.addCheckItem(item)
                            },
                            updateItemEvent: { (item: Checklist.Item) in
                                viewModel.alertError = viewModel.updateCheckItem(item)
                            },
                            dismissSwipeToDeleteTipEvent: {
                                viewModel.dismissSwipeToDeleteTip()
                            }
                        )
                        .onAppear(
                            perform: { viewModel.incrementSwipeToDeleteTip() }
                        )
                    }
                }
                .alert(for: $viewModel.alertError)
            }
            BottomContainerCardView {
                ButtonPrimary(
                    title: Localizable.checklist_add_item(viewModel.checklist.title),
                    action: { viewModel.isEditing = true
                    }
                )
                .padding()
            }
            .navigationBarTitle(Text(Localizable.checklist_title()), displayMode: .inline)
        .screenTracking(screenTrackingName)
        }
    }
}

#if DEBUG
struct ChecklistDetailView_Previews: PreviewProvider {
    static var previews: some View {
        ChecklistDetailView(checklist: Checklist.previewList().first!)
    }
}
#endif
