// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import Combine
import ErrorData
import CMSData

struct SettingsConsentPageView: View {
    @StateObject var viewModel: SettingsPageViewModel

    var body: some View {
        VStack(spacing: 0) {
            SettingsPageView(viewModel: viewModel)
            BottomContainerCardView {
                ButtonPrimary(
                    title: Localizable.settings_consent_remove_title(),
                    action: {
                        App.topViewController?.presentPartialSheet(
                            showCloseButton: true,
                            primaryButton: PartialSheetButton(
                                title: Localizable.settings_consent_remove_title(),
                                action: {
                                    viewModel.removeConsent()
                                }
                            ),
                            secondaryButton:  PartialSheetButton(
                                title: Localizable.common_regret(),
                                action: nil
                            ),
                            content: {
                                removeConsentSheet()
                            }
                        )
                    }
                )
                .padding()
            }
        }
        .alert(for: $viewModel.error)
    }

    @ViewBuilder
    private func removeConsentSheet() -> some View {
        VStack(spacing: Metrics.Spacing.space16) {
            HStack {
                Text(Localizable.settings_consent_remove_title())
                    .applyTextStyle(fontStyle: .headlineM)
                Spacer(minLength: 0)
            }
            Text(Localizable.settings_consent_remove_description_v1())
                .applyTextStyle(fontStyle: .textM)
        }
    }
}

#if DEBUG
struct SettingsConsentPageView_Previews: PreviewProvider {
    static var previews: some View {
        SettingsConsentPageView(
            viewModel: SettingsPageViewModel.preview()
        )
    }
}
#endif
