// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import Combine
import ErrorData
import CMSData

struct SettingsPageView: View, ScreenTrackable {
    @StateObject var viewModel: SettingsPageViewModel

    var screenTrackingName: String {
        "\(String(describing: type(of: self)))_\(viewModel.title)"
    }

    var body: some View {
        DataLoadingView(state: viewModel.state, retryAction: viewModel.fetchData) {
            ScrollView {
                HTMLView(
                    dynamicHeight: $viewModel.htmlViewHeight,
                    isLoading: $viewModel.isWebViewLoading,
                    htmlFilePath: R.file.articleContentHtml()!,
                    html: viewModel.htmlContent,
                    fadeInOnLoad: true,
                    scrollEnabled: false
                )
                .frame(height: viewModel.htmlViewHeight)
                .opacity(viewModel.isWebViewLoading ? 0.0 : 1.0)
                .overlay(
                    HStack {
                        Spacer()
                        ActivityIndicatorView(
                            isAnimating: viewModel.isWebViewLoading,
                            style: .medium,
                            hidesWhenStopped: true
                        )
                        Spacer()
                    }
                ).padding()
            }
        }
        .protectedAppearanceEvents(onAppear: viewModel.fetchData)
        .screenTracking(screenTrackingName)
        .navigationBarTitle(Text(viewModel.title), displayMode: .inline)
    }
}

#if DEBUG
struct SettingsPageView_Previews: PreviewProvider {
    static var previews: some View {
        SettingsPageView(
            viewModel: SettingsPageViewModel.preview()
        )
    }
}
#endif
