// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct FAQView: View, ScreenTrackable {
    @StateObject var viewModel = FAQViewModel()

    var body: some View {
        DataLoadingView(
            state: viewModel.state,
            animateStateChanges: true,
            retryAction: viewModel.fetchData) {
            ScrollView {
                CompatibleVStack(spacing: 16) {
                    ForEach(viewModel.faqItems) { faq in
                        ExpandableTextCardView(
                            title: faq.title,
                            text: faq.text,
                            infoText: Localizable.article_last_updated_on(dateFormatter.string(from: faq.updated)),
                            footerText: nil
                        )
                    }
                }
                .padding()
            }
        }
        .protectedAppearanceEvents(onAppear: viewModel.fetchData)
        .screenTracking(screenTrackingName)
        .navigationBarTitle(Text(Localizable.more_support_faq_title()), displayMode: .inline)
    }
}

private let dateFormatter: DateFormatter = {
    let dateFormatter = DateFormatter()

    dateFormatter.dateStyle = .medium
    dateFormatter.timeStyle = .none

    return dateFormatter
}()

struct FAQView_Previews: PreviewProvider {
    static var previews: some View {
        FAQView()
    }
}
