// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct SupportView: View, ScreenTrackable {
    @StateObject private var viewModel = SupportViewModel()

    let rowHeight: CGFloat = 44

    var body: some View {
        ScrollView {
            VStack {
                CircleImageHeaderView(
                    title: viewModel.title,
                    text: Localizable.more_support_description(),
                    imageUrl: nil,
                    image: Image(R.image.icons.more.support.name)
                )
                .padding(.bottom)
                BaseCardView {
                    VStack(spacing: 0) {
                        NavigationLink(
                            destination: FAQView(),
                            label: {
                                ListItemNavigationView(
                                    title: Localizable.more_support_faq_title(),
                                    description: nil
                                )
                                .frame(minHeight: rowHeight)
                            }
                        )
                        DefaultDivider()
                        NavigationLink(
                            destination: SettingsPageView(
                                viewModel: viewModel.settingsPageViewModel
                            ),
                            label: {
                                ListItemNavigationView(
                                    title: Localizable.more_support_contact_title(),
                                    description: nil
                                )
                                .frame(minHeight: rowHeight)
                            }
                        )
                    }
                    .padding()
                }
            }
            .padding()
        }
        .screenTracking(screenTrackingName)
        .navigationBarTitle(Text(viewModel.title), displayMode: .inline)
    }
}

struct SupportView_Previews: PreviewProvider {
    static var previews: some View {
        SupportView()
    }
}
