// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct OverviewWelcomeHeaderView: View {
    let title: String
    let subtitle: String
    let action: (() -> Void)?
    
    var body: some View {
        VStack(alignment: .leading) {
            HStack {
                Text(title)
                    .applyTextStyle(
                        fontStyle: .textM,
                        textColor: ColorManager.textPrimary.currentColor()
                    )
                Spacer()
                Button(
                    action: action ?? { print("CLICKED WITH NO ACTION :(") },
                    label: {
                        Text(R.string.localizable.overview_start_new_pregnancy_button_title())
                            .applyTextStyle(
                                fontStyle: .buttonM,
                                textColor: ColorManager.textInteractivePrimary.currentColor()
                            )
                    }
                )
                .accessibility(
                    label: Text(R.string.localizable.overview_start_new_pregnancy_button_title())
                )
                .hidden(action == nil)
            }
            Text(subtitle)
                .applyTextStyle(
                    fontStyle: .headlineXL,
                    textColor: ColorManager.textPrimary.currentColor()
                )
                .minimumScaleFactor(0.7)
                .lineLimit(0)
        }
    }
}

struct OverviewWelcomeHeaderView_Previews: PreviewProvider {
    static var previews: some View {
        VStack {
            OverviewWelcomeHeaderView(
                title: "Din graviditet",
                subtitle: "Overblik",
                action: { }
            )
            OverviewWelcomeHeaderView(
                title: "Hej og velkommen",
                subtitle: "Ane Bonde Rasmussen",
                action: nil
            )
        }
        
    }
}
