// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct OverviewPregnantHeaderView: View {
    let monthsIntoPregnancy: Double
    let dueDate: Date?
    let month: Int
    let week: Int
    let gestationAge: String
    let trimester: Int
    let numberOfFetuses: Int
    @Binding var endPregnancyButtonPressed: Bool
    @Binding var updatePregnancyButtonPressed: Bool

    private var dueDateString: String {
        guard let dueDate: Date = dueDate else {
            return Localizable.common_missing_data()
        }
        return OverviewDateFormatter.string(from: dueDate)
    }

    var body: some View {
        VStack(spacing: Metrics.Spacing.space16) {
            OverviewHeaderView(
                monthsIntoPregnancy: monthsIntoPregnancy,
                numberOfFetuses: numberOfFetuses,
                title: Localizable.overview_your_pregnancy_due_date(dueDateString),
                titleButtonAction: { updatePregnancyButtonPressed = true }
            )
            PregnancyDetailsView(
                week: week,
                gestationAge: gestationAge,
                trimester: trimester
            )
            if week >= 40 {
                PregnancyVerificationView(
                    action: {
                        endPregnancyButtonPressed = true
                    }
                )
                .applySmallShadow()
            }
        }
    }
}

struct OverviewWaitingHeaderView_Previews: PreviewProvider {
    static var previews: some View {
        ScrollView {
            VStack {
                OverviewPregnantHeaderView(
                    monthsIntoPregnancy: 3.64,
                    dueDate: Date(),
                    month: 4,
                    week: 19,
                    gestationAge: "(18+5)",
                    trimester: 2,
                    numberOfFetuses: 1,
                    endPregnancyButtonPressed: .constant(false),
                    updatePregnancyButtonPressed: .constant(false)
                )
                OverviewPregnantHeaderView(
                    monthsIntoPregnancy: 8.64,
                    dueDate: Date(),
                    month: 9,
                    week: 37,
                    gestationAge: "38+5",
                    trimester: 4,
                    numberOfFetuses: 2,
                    endPregnancyButtonPressed: .constant(false),
                    updatePregnancyButtonPressed: .constant(false)
                )
            }
            .padding()
        }
    }
}
