// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct PregnancyDetailsView: View {
    let week: Int
    let gestationAge: String
    let trimester: Int
    
    var body: some View {
        BaseCardView {
            ZStack {
                HStack(spacing: Metrics.Spacing.space48) {
                    VStack(alignment: .center, spacing: Metrics.Spacing.space4) {
                        Text("Graviditetsuge") // TODO Localize
                            .applyTextStyle(
                                fontStyle: .textS,
                                textColor: ColorManager.textPrimary.currentColor()
                            )
                        HStack(alignment: .center, spacing: Metrics.Spacing.space4) {
                            Text("\(week).")
                                .applyTextStyle(
                                    fontStyle: .headlineL,
                                    textColor: ColorManager.textPrimary.currentColor()
                                )
                            Text(gestationAge)
                                .applyTextStyle(
                                    fontStyle: .headlineXS,
                                    textColor: ColorManager.textSecondary.currentColor()
                                )
                        }
                    }
                    .frame(maxWidth: .infinity)
                    
                    VStack(alignment: .center, spacing: Metrics.Spacing.space4) {
                        Text("Trimester") // TODO Localize
                            .applyTextStyle(
                                fontStyle: .textS,
                                textColor: ColorManager.textPrimary.currentColor()
                            )
                        Text("\(trimester).")
                            .applyTextStyle(
                                fontStyle: .headlineL,
                                textColor: ColorManager.textPrimary.currentColor()
                            )
                    }
                    .frame(maxWidth: .infinity)
                }
                .padding(Metrics.Spacing.space16)
                
                Divider()
                    .frame(width: 1, height: 40)
                    .background(Color.secondary)
            }
            .frame(maxWidth: .infinity)
        }
    }
}

#Preview {
    PregnancyDetailsView(
        week: 38, 
        gestationAge: "37+6",
        trimester: 3
    )
}
