// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct OnboardingConsentView: View, ScreenTrackable {
    @Environment(\.presentationMode) var presentationMode
    @StateObject var viewModel = OnboardingConsentViewModel()

    var body: some View {
        NavigationView {
            VStack(spacing: Metrics.Spacing.space0) {
                DataLoadingView(state: viewModel.state, retryAction: viewModel.fetchConsent) {
                    ScrollView {
                        HTMLView(
                            dynamicHeight: $viewModel.htmlViewHeight,
                            isLoading: $viewModel.isWebViewLoading,
                            htmlFilePath: R.file.articleContentHtml()!,
                            html: viewModel.htmlContent,
                            fadeInOnLoad: true,
                            scrollEnabled: false
                        )
                        .frame(height: viewModel.htmlViewHeight)
                        .opacity(viewModel.isWebViewLoading ? 0.0 : 1.0)
                        .overlay(
                            HStack {
                                Spacer()
                                ActivityIndicatorView(
                                    isAnimating: viewModel.isWebViewLoading,
                                    style: .medium,
                                    hidesWhenStopped: true
                                )
                                Spacer()
                            }
                        ).padding()
                    }
                }
                BottomContainerCardView {
                    ButtonPrimary(title: Localizable.agreement_button_text()) {
                        viewModel.acceptConsent()
                    }
                    .padding([.leading, .trailing, .bottom])
                    .disabled(!viewModel.isAcceptButtonEnabled)
                    .accessibility(identifier: "consent_accept")
                }
            }
            .navigationBarTitle(Text(Localizable.agreement_title()), displayMode: .inline)
            .navigationBarItems(
                trailing: CloseModalButton(
                    action: {
                        presentationMode.wrappedValue.dismiss()
                    }
                )
            )
            .screenTracking(screenTrackingName)
            .protectedAppearanceEvents(onAppear: viewModel.fetchConsent)
        }
        .accentColor(ColorManager.textPrimary.currentColor())
        .navigationViewStyle(StackNavigationViewStyle())
    }
}

struct OnboardingConsentView_Previews: PreviewProvider {
    static var previews: some View {
        OnboardingConsentView()
    }
}
