// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct OnboardingView: View, ScreenTrackable {
    @DI private var logger: Logger
    
    @StateObject var viewModel = OnboardingViewModel()
    
    var body: some View {
        VStack {
            GeometryReader { geo in
                SUIScrollView(
                    currentPage: $viewModel.currentPage,
                    isPaged: true,
                    bounces: false,
                    showIndicators: false) {
                        HStack(spacing: Metrics.Spacing.space0) {
                            OnboardingPartnersView()
                                .tag(0)
                                .frame(
                                    width: geo.size.width,
                                    height: geo.size.height
                                )
                            OnboardingStepView(
                                backgroundImage: R.image.onboarding.appointments,
                                title: Localizable.onboarding_appointments_title(),
                                subtitle: Localizable.onboarding_appointments_text()
                            )
                            .tag(1)
                            .frame(
                                width: geo.size.width,
                                height: geo.size.height
                            )
                            
                            OnboardingStepView(
                                backgroundImage: R.image.onboarding.knowledge,
                                title: Localizable.onboarding_knowledge_title(),
                                subtitle: Localizable.onboarding_knowledge_text()
                            )
                            .tag(2)
                            .frame(
                                width: geo.size.width,
                                height: geo.size.height
                            )
                        }
                    }
            }
            Spacer()
            PageControl(numberOfPages: 3, currentIndex: viewModel.currentPage)
                .onLongPressGesture(minimumDuration: 3.0) {
                    viewModel.presentAppStoreReviewAlert = true
                }
            if viewModel.isInDemoMode {
                Text("DEMO MODE")
                    .bold()
                    .foregroundColor(.red)
            }
            Spacer(minLength: Metrics.Spacing.space20)
            VStack(spacing: Metrics.Spacing.space12) {
                ButtonTextPrimary(title: Localizable.onboarding_login_get_started_button()) {
                    viewModel.presentConsent = true
                }
                .accessibility(identifier: "login_without_nemid")
            }
            .padding()
        }
        .screenTracking(screenTrackingName)
        .sheetOnBackground(
            isPresented: $viewModel.presentConsent,
            content: {
                SignupView()
            })
//        
//        .sheetOnBackground(
//            isPresented: $viewModel.presentSignup,
//            content: {
//                SignupView()
//            })
        
        .alert(isPresented: $viewModel.presentAppStoreReviewAlert) {
            Alert(
                title: Text("Demo Mode"),
                message: Text("Are you sure you want to enter demo mode?\nYou will see demo data instead of real data."),
                primaryButton: .default(Text("Enter Demo Mode"), action: {
                    viewModel.enterAppStoreDemoMode()
                }),
                secondaryButton: .cancel()
            )
        }
    }
}

struct OnboardingView_Previews: PreviewProvider {
    static var previews: some View {
        Group {
            OnboardingView()
                .previewDevice("iPhone 12 Pro")
            
            OnboardingView()
                .previewDevice("iPhone SE")
        }
    }
}
