//
//  SwiftUIView.swift
//  MinGraviditet
//
//  Created by Casper Christensen on 26/03/2025.
//

import SwiftUI

struct LoginOptionsView1: View {
    var body: some View {
        ScrollView(.vertical, showsIndicators: false) {
            VStack(spacing: Metrics.Spacing.space0) {
                VStack(spacing: Metrics.Spacing.space8) {
                    Text(Localizable.signup_title())
                        .applyTextStyle(
                            fontStyle: .headlineXL,
                            textColor: ColorManager.textPrimary.currentColor()
                        )
                        .padding(.horizontal, Metrics.Spacing.space16)
                    
                    Text(Localizable.signup_description())
                        .applyTextStyle(
                            fontStyle: .textM,
                            textColor: ColorManager.textPrimary.currentColor()
                        )
                        .padding(.horizontal, Metrics.Spacing.space16)
                    
                    Spacer()
                    
                    Image(R.image.illustrations.startLoginOptions.name)
                        .renderingMode(.original)
                        .resizable()
                        .aspectRatio(contentMode: .fit)
                        .padding(.horizontal, 0)
                    
                    VStack {
                        ButtonPrimary(
                            title: Localizable.signup_proceed_with_mitid_button(),
                            action: { print("Log ind med MitID")}
                        )
                        ButtonPrimarySubtle(
                            title: Localizable.signup_proceed_without_login_button(),
                            action: { print("Fortsæt uden log ind") }
                        )
                    }
                    .padding(.horizontal, Metrics.Spacing.space16)
                    .padding(.top, Metrics.Spacing.space16)
                }
                
                Text(Localizable.signup_disclaimer())
                    .applyTextStyle(
                        fontStyle: .textS,
                        textColor: ColorManager.textSecondary.currentColor()
                    )
                    .multilineTextAlignment(.center)
                    .padding(Metrics.Spacing.space24)
            }
            .padding(.top, Metrics.Spacing.space48)
        }
        .background(ColorManager.bgNeutralPrimary.currentColor())
    }
}


struct SignupView: View {
    @StateObject var viewModel = SignupViewModel()
    
    @State private var showStuff1 = false
    @State private var showStuff2 = false

    
    var body: some View {
        ScrollView(.vertical, showsIndicators: false) {
                VStack(spacing: Metrics.Spacing.space8) {
                    Text(Localizable.signup_title())
                        .applyTextStyle(
                            fontStyle: .headlineXL,
                            textColor: ColorManager.textPrimary.currentColor()
                        )
                        .padding(.horizontal, Metrics.Spacing.space16)
                    
                    Text(Localizable.signup_description())
                        .applyTextStyle(
                            fontStyle: .textM,
                            textColor: ColorManager.textPrimary.currentColor()
                        )
                        .padding(.horizontal, Metrics.Spacing.space16)
                    
                    Spacer()
                    
                    Image(R.image.illustrations.startLoginOptions.name)
                        .renderingMode(.original)
                        .resizable()
                        .aspectRatio(contentMode: .fit)
                        .padding(.horizontal, 0)
                    
                    VStack {
                        Text(Localizable.signup_disclaimer())
                            .applyTextStyle(
                                fontStyle: .textS,
                                textColor: ColorManager.textSecondary.currentColor()
                            )
                            .multilineTextAlignment(.center)
                            .padding(Metrics.Spacing.space16)
                        ButtonPrimary(
                            title: Localizable.signup_proceed_with_mitid_button(),
                            action: { showStuff1 = true }
                        )
                        ButtonPrimarySubtle(
                            title: Localizable.signup_proceed_without_login_button(),
                            action: { showStuff2 = true }
                        )
                    }
                    .padding(.horizontal, Metrics.Spacing.space16)
                }
            .padding(.top, Metrics.Spacing.space48)
            .padding(.bottom, Metrics.Spacing.space32)

        }
        .sheetOnBackground(
            isPresented: $showStuff1,
            content: {
                OnboardingConsentView()
            }
        )
        .background(ColorManager.bgNeutralPrimary.currentColor())
    }
}

#Preview {
    LoginOptionsView1()
}

#Preview {
    SignupView()
}
