// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct LoadingButton: View {
    @Environment(\.isEnabled) var isEnabled: Bool
    
    @State var didAppear: Bool = false
    
    let title: String
    let isLoading: Bool
    let action: () -> Void
    
    init(
        title: String,
        isLoading: Bool = false,
        action: @escaping () -> Void
    ) {
        self.title = title
        self.isLoading = isLoading
        self.action = action
    }

    var body: some View {
        ZStack {
            ActivityIndicatorView(
                isAnimating: isLoading,
                color: .red,
                style: .large,
                hidesWhenStopped: false
            )
            .opacity(isLoading ? 1.0 : 0.0)

            ButtonPrimary(
                title: title,
                action: action
            )
            .opacity(isLoading ? 0.0 : 1.0)
            .disabled(!isEnabled)
        }
        .animation(.default, value: isLoading)
    }
}

struct PrimaryLoadingButton_Previews: PreviewProvider {
    static var previews: some View {
        VStack {
            LoadingButton(
                title: "Test",
                isLoading: false,
                action: { }
            )
            LoadingButton(
                title: "Test 2",
                isLoading: true,
                action: { }
            )
            LoadingButton(
                title: "Test 3",
                isLoading: false,
                action: { }
            )
            .disabled(true)
            LoadingButton(
                title: "Test 4",
                isLoading: false,
                action: { }
            )
            LoadingButton(
                title: "Test 4",
                isLoading: true,
                action: { }
            )
            LoadingButton(
                title: "Test 5",
                isLoading: false,
                action: { }
            )
            .disabled(true)
            Spacer()
        }
        .padding()
    }
}
