// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct BottomContainerCardView<Content: View>: View {
    let color: Color
    let backgroundColor: Color
    let content: Content
    private let clippingOffset: CGFloat = 10
    private let height: CGFloat = Metrics.Sizes.cardCornerRadius * 2

    init(
        color: Color = ColorManager.bgSurfaceNeutralSecondary.currentColor(),
        backgroundColor: Color = ColorManager.bgNeutralPrimary.currentColor(),
        @ViewBuilder content: () -> Content) {
        self.color = color
        self.backgroundColor = backgroundColor
        self.content = content()
    }

    var body: some View {
        VStack(alignment: .leading, spacing: 0) {
            ZStack { // Rounded card look for bottom
                backgroundColor
                color
                    .cornerRadius(config: .top(radius: Metrics.Sizes.cardCornerRadius))
                    .applySmallShadow()
                    .clipShape(
                        Rectangle()
                            .size(
                                width: UIScreen.main.bounds.width,
                                height: height + clippingOffset
                            )
                            .offset(x: 0, y: -clippingOffset)
                    )
            }
            .frame(height: height)
            VStack {
                content
            }
            .padding(.top, -Metrics.Sizes.cardCornerRadius)
        }
        .background(color)
    }
}

struct FullWidthCardView_Previews: PreviewProvider {
    static var previews: some View {
        VStack {
            Spacer()
            Text("Hello!")
            BottomContainerCardView(
                color: .white,
                backgroundColor: .pink,
                content: {
                    VStack {
                        Text("PEW PEW")
                        Text("PEW PEW")
                        Text("PEW PEW")
                    }
            })
        }
        .background(Color.pink)
    }
}
