//// The MIT License
////
//// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
////
//// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
////
//// Permission is hereby granted, free of charge, to any person obtaining a copy of
//// this software and associated documentation files (the "Software"), to deal in
//// the Software without restriction, including without limitation the rights to
//// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
//// of the Software, and to permit persons to whom the Software is furnished to do
//// so, subject to the following conditions:
////
//// The above copyright notice and this permission notice shall be included in all
//// copies or substantial portions of the Software.
////
//// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
//// SOFTWARE.
//
//import UIKit
//import SwiftUI
//import Charts
//
//final class MeasurementsLineChart : LineChartView {
//    let yData: AxisData
//    let xData: AxisData
//    let dataValues: [ChartValue]
//    let normalValueRanges: ChartNormalValues
//    var selectedEntry: ChartValue?
//    
//    required init(
//        yData: AxisData,
//        xData: AxisData,
//        dataValues: [ChartValue],
//        normalValueRanges: ChartNormalValues
//    ) {
//        self.yData = yData
//        self.xData = xData
//        self.dataValues = dataValues
//        self.normalValueRanges = normalValueRanges
//        super.init(frame: .zero)
//        
//        self.isUserInteractionEnabled = true
//        self.setScaleEnabled(false)
//        self.pinchZoomEnabled = false
//        self.doubleTapToZoomEnabled = false
//        
//        setup()
//        setupTapGesture()
//    }
//    
//    required init?(coder aDecoder: NSCoder) {
//        fatalError("init(coder:) has not been implemented")
//    }
//    
//    private func setupTapGesture() {
//        let tapGesture = UITapGestureRecognizer(target: self, action: #selector(handleChartTap(_:)))
//        tapGesture.numberOfTapsRequired = 1
//        self.addGestureRecognizer(tapGesture)
//    }
//
//    @objc private func handleChartTap(_ sender: UITapGestureRecognizer) {
//        let touchLocation = sender.location(in: self)
//        var closestEntry: ChartValue?
//        var closestDistance: CGFloat = CGFloat.greatestFiniteMagnitude
//
//        for entry in dataValues {
//            let pixelPoint = getPixelForValue(x: entry.x, y: entry.y)
//            let distance = distanceBetween(touchLocation, pixelPoint)
//
//            if distance < closestDistance {
//                closestDistance = distance
//                closestEntry = entry
//            }
//        }
//
//        if let selectedValue = closestEntry, closestDistance < 15 {
//            selectedEntry = selectedValue
//            self.setNeedsDisplay()
//        } else {
//            selectedEntry = nil
//        }
//    }
//    
//    
//    func getPixelForValue(x: Double, y: Double) -> CGPoint {
//        let transformer = self.getTransformer(forAxis: .left)
//        return CGPoint(x: x, y: y).applying(transformer.valueToPixelMatrix)
//    }
//
//    private func distanceBetween(_ p1: CGPoint, _ p2: CGPoint) -> CGFloat {
//        sqrt(pow(p1.x - p2.x, 2) + pow(p1.y - p2.y, 2))
// }
//
//    private func setup() {
//        renderer = MeasurementsLineChartRenderer(dataProvider: self, animator: chartAnimator, viewPortHandler: viewPortHandler)
//        
//        let transformer = getTransformer(forAxis: .left)
//        setupXAxis(transformer)
//        setupLeftAxis(transformer)
//        
//        noDataText = ""
//        rightAxis.enabled = false
//        legend.enabled = false
//        
//        setupDataSets()
//    }
//    
//    private func setupXAxis(_ transformer: Transformer) {
//        configureXAxisFormat()
//        configureXAxisLimits()
//        configureXAxisAppearance()
//
//        xAxisRenderer = MeasurementsLineChartXAxisRenderer(
//            viewPortHandler: viewPortHandler,
//            axis: xAxis,
//            transformer: transformer
//        )
//    }
//    
//    private func configureXAxisFormat() {
//        xAxis.valueFormatter = MeasurementLineChartXAxisLabelFormatter(
//            unit: xData.unit,
//            values: xData.values
//        )
//    }
//    
//    private func configureXAxisLimits() {
//        xAxis.axisMinimum = (xData.values.first ?? 0) - 0.1  // Gives extra space
//        xAxis.axisMaximum = (xData.values.last ?? 0) + 0.1   // Gives extra space
//        xAxis.granularity = 5.0
//        xAxis.granularityEnabled = true
//    }
//    
//    private func configureXAxisAppearance() {
//        xAxis.labelCount = xData.values.count
//        xAxis.labelPosition = .bottom
//        xAxis.yOffset = 8
//        xAxis.labelFont = FontStyle.textXSStrong.font
//        xAxis.labelTextColor = ColorManager.textPrimary.currentUIColor()
//        xAxis.drawGridLinesEnabled = false
//        xAxis.drawAxisLineEnabled = true
//        extraRightOffset = 24  // Prevents last label from being cut off
//    }
//    
//    private func setupLeftAxis(_ transformer: Transformer) {
//        configureLeftAxisFormat()
//        configureLeftAxisLimits()
//        configureLeftAxisAppearance()
//
//        leftYAxisRenderer = MeasurementsLineChartYAxisRenderer(
//            viewPortHandler: viewPortHandler,
//            axis: leftAxis,
//            transformer: transformer
//        )
//    }
//    
//    private func configureLeftAxisFormat() {
//        leftAxis.valueFormatter = MeasurementLineChartYAxisLabelFormatter(unit: yData.unit)
//        leftAxis.spaceMin = 1
//        leftAxis.spaceMax = 1
//    }
//    
//    private func configureLeftAxisLimits() {
//        leftAxis.axisMinimum = yData.values.first ?? 0
//        leftAxis.axisMaximum = yData.values.last ?? 0
//        leftAxis.labelCount = yData.values.count
//    }
//    
//    private func configureLeftAxisAppearance() {
//        leftAxis.drawAxisLineEnabled = false
//        leftAxis.labelFont = FontStyle.textXSStrong.scaledUIFont()
//        leftAxis.labelTextColor = ColorManager.textPrimary.currentUIColor()
//        leftAxis.drawGridLinesEnabled = true
//        leftAxis.drawLabelsEnabled = true
//        leftAxis.drawLimitLinesBehindDataEnabled = true
//    }
//    
//    
//    private func setupDataSets() {
//        let valuesDataSet = MeasurementLineChartValueDataSet(
//            entries: dataValues.toChartEntries()
//        )
//        valuesDataSet.lineWidth = 0
//        valuesDataSet.drawFilledEnabled = false // used to colors the chart without areas
//        
//        let areaDataSet = MeasurementLineChartAreaDataSet(
//            lower: normalValueRanges.lower.toChartEntries(),
//            upper: normalValueRanges.upper.toChartEntries(),
//            middle: normalValueRanges.middle.toChartEntries()
//        )
//        
//        data = LineChartData(
//            dataSets: [
//                areaDataSet,
//                valuesDataSet
//            ]
//        )
//    }
//}
//
//struct SUIMeasurementsLineChart: UIViewRepresentable {
//    let dataModel: LineChartDataModel
//
//    func makeUIView(context: Context) -> MeasurementsLineChart {
//        MeasurementsLineChart(
//            yData: dataModel.yData,
//            xData: dataModel.xData,
//            dataValues: dataModel.values,
//            normalValueRanges: dataModel.normalValues
//        )
//    }
//    
//    func updateUIView(_ uiView: MeasurementsLineChart, context: Context) {}
//}
//
//fileprivate extension Sequence where Element == ChartValue {
//    func toChartEntries() -> [ChartDataEntry] {
//        self.map({ ChartDataEntry(x: $0.x, y: $0.y) })
//    }
//}
//
//
//// TODO MOVE
