// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation

struct ChartValue {
    let x: Double
    let y: Double
}

extension ChartValue {
    static func mocklist() -> [ChartValue] {
        [
            ChartValue(x: 14, y: 0.9),
            ChartValue(x: 20, y: 1.8),
            ChartValue(x: 28, y: 2.8),
            ChartValue(x: 38, y: 3.6)
            
        ]
    }
}

extension ChartValue: Identifiable {
    var id: String {
        "\(x)-\(y)"
    }
}

struct ChartNormalValues {
    let upper: [ChartValue]
    let middle: [ChartValue]
    let lower: [ChartValue]
}

extension ChartNormalValues {
    
    static func mock() -> ChartNormalValues {
        ChartNormalValues(
            upper: [
                ChartValue(x: 10, y: 0.85),
                ChartValue(x: 12, y: 1.0),
                ChartValue(x: 14, y: 1.3),
                ChartValue(x: 16, y: 1.6),
                ChartValue(x: 18, y: 1.9),
                ChartValue(x: 20, y: 2.3),
                ChartValue(x: 22, y: 2.6),
                ChartValue(x: 24, y: 2.9),
                ChartValue(x: 26, y: 3.1),
                ChartValue(x: 28, y: 3.3),
                ChartValue(x: 30, y: 3.4),
                ChartValue(x: 32, y: 3.6),
                ChartValue(x: 34, y: 3.7),
                ChartValue(x: 36, y: 3.8),
                ChartValue(x: 38, y: 3.9),
                ChartValue(x: 40, y: 4.0),
                ChartValue(x: 42, y: 4.1),
                ChartValue(x: 45, y: 4.2)
            ],
            middle: [
                ChartValue(x: 10, y: 0.4),
                ChartValue(x: 12, y: 0.7),
                ChartValue(x: 14, y: 1.0),
                ChartValue(x: 16, y: 1.3),
                ChartValue(x: 18, y: 1.6),
                ChartValue(x: 20, y: 2.0),
                ChartValue(x: 22, y: 2.3),
                ChartValue(x: 24, y: 2.6),
                ChartValue(x: 26, y: 2.8),
                ChartValue(x: 28, y: 3.0),
                ChartValue(x: 30, y: 3.1),
                ChartValue(x: 32, y: 3.3),
                ChartValue(x: 34, y: 3.4),
                ChartValue(x: 36, y: 3.5),
                ChartValue(x: 38, y: 3.6),
                ChartValue(x: 40, y: 3.7),
                ChartValue(x: 42, y: 3.8),
                ChartValue(x: 45, y: 3.9)
            ],
            lower: [
                ChartValue(x: 10, y: 0.0),
                ChartValue(x: 12, y: 0.4),
                ChartValue(x: 14, y: 0.7),
                ChartValue(x: 16, y: 1.0),
                ChartValue(x: 18, y: 1.3),
                ChartValue(x: 20, y: 1.7),
                ChartValue(x: 22, y: 2.0),
                ChartValue(x: 24, y: 2.3),
                ChartValue(x: 26, y: 2.5),
                ChartValue(x: 28, y: 2.7),
                ChartValue(x: 30, y: 2.8),
                ChartValue(x: 32, y: 3.0),
                ChartValue(x: 34, y: 3.1),
                ChartValue(x: 36, y: 3.2),
                ChartValue(x: 38, y: 3.3),
                ChartValue(x: 40, y: 3.4),
                ChartValue(x: 42, y: 3.5),
                ChartValue(x: 45, y: 3.6)
            ]
        )
    }
}
