//// The MIT License
////
//// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
////
//// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
////
//// Permission is hereby granted, free of charge, to any person obtaining a copy of
//// this software and associated documentation files (the "Software"), to deal in
//// the Software without restriction, including without limitation the rights to
//// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
//// of the Software, and to permit persons to whom the Software is furnished to do
//// so, subject to the following conditions:
////
//// The above copyright notice and this permission notice shall be included in all
//// copies or substantial portions of the Software.
////
//// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
//// SOFTWARE.
//
//import UIKit
//import Charts
//
//enum TooltipPlacement {
//    case upRight
//    case upMiddle
//    case upLeft
//    case downRight
//    case downMiddle
//    case downLeft
//}
//
//final class MeasurementsLineChartRenderer: LineChartRenderer {
//    static let dotSize: CGFloat = 12
//    static let dotRadius: CGFloat = dotSize / 2
//
//    var dataSets: [ChartDataSetProtocol] {
//        dataProvider?.lineData?.dataSets ?? []
//    }
//
//    override func drawExtras(context: CGContext) {
//        super.drawExtras(context: context)
//        guard let chart = dataProvider as? MeasurementsLineChart else { return }
//        
//        for dataSet in dataSets {
//            if let valueDataSet = dataSet as? MeasurementLineChartValueDataSet {
//                for entryIndex in 0 ..< valueDataSet.count {
//                    if let entry = valueDataSet.entryForIndex(entryIndex) {
//                        drawValueCircle(entry: entry, dataSet: dataSet, in: context)
//                    }
//                }
//            }
//        }
//      
//        if let selected = chart.selectedEntry {
//            let tooltipPlacement = calculateTooltipPlacement(for: selected, in: chart)
//            drawTooltip(for: selected, in: context, placement: tooltipPlacement)
//        }
//    }
//    
//    override func drawLinear(context: CGContext, dataSet: LineChartDataSetProtocol) {
//        
//        // Do not draw line for values.
//        if let dataSet = dataSet as? MeasurementLineChartAreaDataSet {
//            context.saveGState()
//            context.setFillColor(ColorManager.iconInteractivePrimary.currentUIColor().withAlphaComponent(0.08).cgColor)
//            if let transformer = dataProvider?.getTransformer(forAxis: dataSet.axisDependency) {
//                let valuesForArea = [
//                    dataSet.upperEntries,
//                    dataSet.lowerEntries.reversed()
//                ].flatMap({ $0 })
//
//                let bezier = UIBezierPath()
//
//                for areaValue in valuesForArea {
//                    let point = CGPoint(x: areaValue.x, y: areaValue.y).applying(transformer.valueToPixelMatrix)
//                    if areaValue === valuesForArea.first {
//                        bezier.move(to: point)
//                    }
//                    bezier.addLine(to: point)
//                }
//                bezier.close()
//                bezier.fill()
//            }
//            context.restoreGState()
//        }
//        // Draws middle line for area and draws value line for values.
//        super.drawLinear(context: context, dataSet: dataSet)
//    }
//    
//    private func drawValueCircle(entry: ChartDataEntry, dataSet: ChartDataSetProtocol, in context: CGContext) {
//
//        guard let transformer = dataProvider?.getTransformer(forAxis: dataSet.axisDependency) else {
//            return
//        }
//
//        let pixelPoint = CGPoint(x: entry.x, y: entry.y).applying(transformer.valueToPixelMatrix)
//        var rect = CGRect(origin: pixelPoint, size: CGSize(width: Self.dotSize, height: Self.dotSize))
//
//        rect.origin.x = pixelPoint.x - Self.dotRadius
//        rect.origin.y = pixelPoint.y - Self.dotRadius
//        rect.size.width = Self.dotSize
//        rect.size.height = Self.dotSize
//
//        context.saveGState()
//        context.setStrokeColor(UIColor.white.cgColor)
//        context.setLineWidth(5)
//        context.setFillColor(ColorManager.iconDecorativePurpleHeart.currentUIColor().cgColor)
//        context.setShadow(offset: .zero, blur: 4, color: ColorManager.shadow.currentUIColor().withAlphaComponent(0.5).cgColor)
//
//        context.strokeEllipse(in: rect)
//        context.fillEllipse(in: rect)
//
//        context.restoreGState()
//    }
//    
//    private func drawTooltip(for entry: ChartValue, in context: CGContext, placement: TooltipPlacement) {
//        guard let chart = dataProvider as? MeasurementsLineChart else { return }
//        let transformer = chart.getTransformer(forAxis: .left)
//        let pixelPoint = CGPoint(x: entry.x, y: entry.y).applying(transformer.valueToPixelMatrix)
//
//        let labelText = "\(Int(entry.x)) uger, \(Int(entry.y * 1000)) g" // Format text
//        let attributes: [NSAttributedString.Key: Any] = [
//            .font: FontStyle.textS.scaledUIFont(),
//            .foregroundColor: ColorManager.textWhite.currentUIColor()
//        ]
//
//        // Calculate the size of the text with padding included
//        let textSize = labelText.size(withAttributes: attributes)
//        let tooltipWidth = textSize.width + Metrics.Spacing.space24
//        let tooltipHeight = textSize.height + Metrics.Spacing.space24
//        let labelRect = createLabelRect(pixelPoint: pixelPoint, tooltipWidth: tooltipWidth, tooltipHeight: tooltipHeight, placement: placement)
//
//        context.saveGState()
//
//        
//        let tooltipPath = UIBezierPath(roundedRect: labelRect, cornerRadius: Metrics.Spacing.space12)
//        context.setFillColor(ColorManager.bgSurfaceInteractivePrimary.currentUIColor().cgColor)
//        context.addPath(tooltipPath.cgPath)
//        context.fillPath()
//
//        // Draw the text centered in the bubble with additional padding
//        let textRect = CGRect(
//            x: labelRect.origin.x + Metrics.Spacing.space12,
//            y: labelRect.origin.y + Metrics.Spacing.space12,
//            width: textSize.width,
//            height: textSize.height
//        )
//        labelText.draw(in: textRect, withAttributes: attributes)
//
//        context.restoreGState()
//    }
//    
//    private func createLabelRect(pixelPoint: CGPoint, tooltipWidth: CGFloat, tooltipHeight: CGFloat, placement: TooltipPlacement) -> CGRect {
//        let offset: CGFloat = 10
//
//        switch placement {
//        case .upRight:
//            return CGRect(
//                x: pixelPoint.x,
//                y: pixelPoint.y - tooltipHeight - offset,
//                width: tooltipWidth,
//                height: tooltipHeight
//            )
//
//        case .upMiddle:
//            return CGRect(
//                x: pixelPoint.x - tooltipWidth / 2,
//                y: pixelPoint.y - tooltipHeight - offset,
//                width: tooltipWidth,
//                height: tooltipHeight
//            )
//
//        case .upLeft:
//            return CGRect(
//                x: pixelPoint.x - tooltipWidth,
//                y: pixelPoint.y - tooltipHeight - offset,
//                width: tooltipWidth,
//                height: tooltipHeight
//            )
//
//        case .downRight:
//            return CGRect(
//                x: pixelPoint.x,
//                y: pixelPoint.y + offset,
//                width: tooltipWidth,
//                height: tooltipHeight
//            )
//
//        case .downMiddle:
//            return CGRect(
//                x: pixelPoint.x - tooltipWidth / 2,
//                y: pixelPoint.y + offset,
//                width: tooltipWidth,
//                height: tooltipHeight
//            )
//
//        case .downLeft:
//            return CGRect(
//                x: pixelPoint.x - tooltipWidth,
//                y: pixelPoint.y + offset,
//                width: tooltipWidth,
//                height: tooltipHeight
//            )
//        }
//    }
//    
//    private func calculateTooltipPlacement(for selected: ChartValue, in chart: MeasurementsLineChart) -> TooltipPlacement {
//        let yMin = chart.yData.values.first ?? 0
//        let yMax = chart.yData.values.last ?? 0
//        let chartHeight = yMax - yMin
//        
//        let relativeDataPointHeight = selected.y - yMin
//        let chartHeightPercentage = relativeDataPointHeight / chartHeight
//
//        let xMaxValue = chart.xData.values.last ?? 0
//        var placement: TooltipPlacement
//        
//        // Bottom two-thirds
//        if chartHeightPercentage < (2.0 / 3.0) {
//            if selected.x < xMaxValue / 3.0 {
//                placement = .upRight
//            } else if selected.x <= xMaxValue * 2.0 / 3.0 {
//                placement = .upMiddle
//            } else {
//                placement = .upLeft
//            }
//        } else {
//            // Top third
//            if selected.x < xMaxValue / 3.0 {
//                placement = .downRight
//            } else if selected.x <= xMaxValue * 2.0 / 3.0 {
//                placement = .downMiddle
//            } else {
//                placement = .downLeft
//            }
//        }
//        return placement
//    }
//}
