// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct CircularProgressBar: View {
    var progress: Double

    let lineWidth: CGFloat
    let padding: CGFloat

    var backgroundColor: Color?

    var body: some View {
        InnerShadowCircleView(backgroundColor: backgroundColor) {
            Circle()
                .trim(from: 0, to: CGFloat(progress))
                .stroke(style: StrokeStyle(lineWidth: lineWidth, lineCap: .round))
                .fill(ColorManager.iconDecorativePurpleHeart.currentColor())
                .animation(.easeOut(duration: 0.2))
                .rotationEffect(Angle(degrees: -90))
                .padding(lineWidth / CGFloat(2) + padding) // lineWidth / 2 + padding, since the stroke is drawn on center of the edge
        }
    }
}

struct CircularProgressBar_Previews: PreviewProvider {
    static var previews: some View {
        VStack(spacing: 25) {
            CircularProgressBar(progress: 0.0, lineWidth: 3, padding: 8)
                .frame(width: 94, height: 94)
            CircularProgressBar(progress: 0.35, lineWidth: 3, padding: 4)
                .frame(width: 94, height: 94)
            CircularProgressBar(progress: 0.35, lineWidth: 3, padding: 0)
                .frame(width: 40, height: 40)
            CircularProgressBar(progress: 0.8, lineWidth: 12, padding: 8, backgroundColor: Color.pink)
            CircularProgressBar(progress: 1.0, lineWidth: 12, padding: 8)

        }.padding()
    }
}
