// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct CircularProgressBarWithPercentage: View {
    var progress: Double
    let lineWidth: CGFloat
    let linePadding: CGFloat
    let fontStyle: FontStyle

    init(
        progress: Double,
        lineWidth: CGFloat,
        linePadding: CGFloat,
        fontStyle: FontStyle = .headlineL
    ) {
        self.progress = progress
        self.lineWidth = lineWidth
        self.linePadding = linePadding
        self.fontStyle = fontStyle
    }

    private var contentPadding: CGFloat {
        linePadding * 2 + lineWidth
    }

    var body: some View {
        ZStack {
            CircularProgressBar(
                progress: progress,
                lineWidth: lineWidth,
                padding: linePadding
            )
            Circle()
            .fill(ColorManager.bgSurfaceNeutralPrimary.currentColor())
                .padding(contentPadding)
            Text("\(Int(round(progress * 100)))%")
                .applyTextStyle(
                    fontStyle: fontStyle,
                    textColor: ColorManager.textBrand.currentColor()
                )
                .minimumScaleFactor(0.1)
                .padding(contentPadding + 5)
            
        }
    }
}

struct CircularProgressBarWithPercentage_Previews: PreviewProvider {
    static var previews: some View {
        VStack(spacing: 10) {
            CircularProgressBarWithPercentage(
                progress: 0.0,
                lineWidth: 3,
                linePadding: 0
            )
            .frame(width: 40, height: 40)

            CircularProgressBarWithPercentage(
                progress: 0.0,
                lineWidth: 3,
                linePadding: 0
            )
            .frame(width: 40, height: 40)

            CircularProgressBarWithPercentage(
                progress: 0.5,
                lineWidth: 3,
                linePadding: 0
            )
            .frame(width: 40, height: 40)

            CircularProgressBarWithPercentage(
                progress: 1.0,
                lineWidth: 3,
                linePadding: 0
            )
            .frame(width: 40, height: 40)

            CircularProgressBarWithPercentage(
                progress: 0.0,
                lineWidth: 3,
                linePadding: 5
            )
            .frame(width: 94, height: 94)

            CircularProgressBarWithPercentage(
                progress: 0.5,
                lineWidth: 3,
                linePadding: 5
            )
            .frame(width: 94, height: 94)

            CircularProgressBarWithPercentage(
                progress: 0.73467344,
                lineWidth: 3,
                linePadding: 5
            )
            .frame(width: 94, height: 94)

            CircularProgressBarWithPercentage(
                progress: 1,
                lineWidth: 3,
                linePadding: 5
            )
            .frame(width: 94, height: 94)
        }
    }
}
