// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import SwiftUI

struct DataTableCellHeightPreferenceKey: PreferenceKey {
    static var defaultValue = DataTableCellDetermineHeightResult(row: -1, height: 0)
    static func reduce(value: inout DataTableCellDetermineHeightResult, nextValue: () -> DataTableCellDetermineHeightResult) {
        let next = nextValue()
        if next.row == value.row && next.height > value.height {
            value = next
        }
    }
}

struct DataTableCellDetermineHeightResult: Equatable {
    let id = UUID() // iOS 13 needs to have unique models to update for all cells in the same row
    let row: Int
    let height: CGFloat
}

struct DataTableCellDetermineHeight: View {
    typealias Key = DataTableCellHeightPreferenceKey

    let row: Int
    var body: some View {
        GeometryReader { proxy in
            Color.clear
                .anchorPreference(key: Key.self, value: .bounds) { anchor in
                    DataTableCellDetermineHeightResult(row: row, height: proxy[anchor].size.height)
                }
        }
    }
}
