// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import UIData

struct TwoColumnDataTable: View {
    let rows: [[DataTableCell]]

    private var cellHeight: CGFloat {
        // Infinity crashes on iOS 13
        if #available(iOS 14, *) {
            return .infinity
        } else {
            return 64
        }
    }

    var body: some View {
        VStack(alignment: .leading, spacing: 0) {
            ForEach(rows.indices) { (rowIndex) in
                let cellsForRow: [DataTableCell] = rows[rowIndex]
                HStack(spacing: 0) {
                    ForEach(cellsForRow.indices) { (index) in
                        let cell: DataTableCell = cellsForRow[index]
                        DataTableCellView(
                            cell: cell,
                            rowNumber: rowIndex,
                            height: cellHeight,
                            width: index == 0 ? 144 : .infinity,
                            colorOddRows: false
                        )
                        if cellsForRow.last?.id != cell.id {
                            DefaultDivider()
                        }
                    }
                }
                .tag(rowIndex)
            }
        }
    }
}

struct TwoColumnDataTable_Previews: PreviewProvider {
    static var previews: some View {
        TwoColumnDataTable(
            rows: [
                [
                    DataTableCell(id: "1", value: "Uge", type: .text),
                    DataTableCell(id: "2", value: "14+3", type: .text)
                ],
                [
                    DataTableCell(id: "3", value: "Skønnet fostervægt i 3 linjer", type: .infoButton({ })),
                    DataTableCell(id: "4", value: "1800 g", type: .text)
                ],
                [
                    DataTableCell(id: "5", value: "Fosters stilling", type: .infoButton({ })),
                    DataTableCell(id: "6", value: "H", type: .text)
                ]
            ]
        )
    }
}
