// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct CircleImageHeaderView: View {
    let title: String
    let text: String
    let imageUrl: URL?
    let image: Image?

    var body: some View {
        VStack(spacing: Metrics.Spacing.space12) {
            InnerShadowCircleView {
                ZStack {
                    CircleContentShadowView()
                        .frame(size: 66)
                    if let imageUrl = imageUrl {
                        URLImage(
                            url: imageUrl,
                            imageView: { uiImage in
                                Image(uiImage: uiImage)
                                    .headerImageSetup()

                            },
                            placeholderView: { ActivityIndicatorView(isAnimating: true, style: .medium, hidesWhenStopped: true) },
                            errorView: { _ in EmptyView() }
                        )
                    } else if let image = image {
                        image
                            .headerImageSetup()
                    }
                }
            }
            .frame(size: 90)
            .accessibility(hidden: true)

            VStack(spacing: Metrics.Spacing.space4) {
                Text(title)
                    .applyTextStyle(
                        fontStyle: .headlineL,
                        textColor: ColorManager.textPrimary.currentColor()
                    )
                    .multilineTextAlignment(.center)
                Text(text)
                    .applyTextStyle(
                        fontStyle: .textM,
                        textColor: ColorManager.textSecondary.currentColor()
                    )
                    .multilineTextAlignment(.center)
                    .fixedSize(horizontal: false, vertical: true)
            }
        }
    }
}

private extension Image {
    func headerImageSetup() -> some View {
        self
            .renderingMode(.original)
            .resizable()
            .aspectRatio(contentMode: .fit)
            .padding(25)
    }
}

struct CircleImageHeaderView_Previews: PreviewProvider {
    static var previews: some View {
        VStack {
            CircleImageHeaderView(
                title: "Test",
                text: String.loremIpsum(.small),
                imageUrl: URL(string: "https://cataas.com/cat")!,
                image: nil
            )
            CircleImageHeaderView(
                title: "Test 2",
                text: String.loremIpsum(.small),
                imageUrl: nil,
                image: Image(R.image.icons.journal.measurement.name)
            )
            CircleImageHeaderView(
                title: "Test 3",
                text: String.loremIpsum(.small),
                imageUrl: nil,
                image: Image(R.image.icons.journal.bulb.name)
            )
        }
    }
}
