// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct ListPickerValue: Identifiable {
    let id: String
    let name: String
}

struct ListPickerView: View {
    @Environment(\.presentationMode) var presentationMode
    let title: String
    let values: [ListPickerValue]
    @Binding var selectedPickerValueId: String?

    var body: some View {
        ScrollView {
            CompatibleVStack(spacing: 0) {
                ForEach(values) { value in
                    VStack(spacing: 0) {
                        Button(action: {
                            selectedPickerValueId = value.id
                            presentationMode.wrappedValue.dismiss()
                        }, label: {
                            HStack {
                                Text(value.name)
                                    .applyTextStyle(fontStyle: .headlineXS)
                                    .multilineTextAlignment(.leading)
                                Spacer()
                                Image(R.image.icons.basic.check.name)
                                    .renderingMode(.template)
                                    .foregroundColor(ColorManager.iconDecorativePurpleHeart.currentColor())
                                   
                                    .hidden(selectedPickerValueId != value.id)
                            }
                            .frame(maxWidth: .infinity, minHeight: 44)
                        })
                        DefaultDivider()
                    }
                }
            }
            .padding()
        }
        .navigationBarTitle(Text(title), displayMode: .inline)
    }
}

struct ListPickerView_Previews: PreviewProvider {
    static var previews: some View {
        ListPickerView(
            title: "Test",
            values: [
                ListPickerValue(id: "1", name: "Test 1"),
                ListPickerValue(id: "2", name: "Test 2"),
                ListPickerValue(id: "3", name: "Test 3")
            ],
            selectedPickerValueId: .constant("2")
        )
    }
}
