// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

enum PINCodeDotState {
    case empty
    case active
    case filled
    case loading
    case error

    var foregroundColor: Color {
        switch self {
        case .empty:
            return ColorManager.bgSurfaceNeutralSecondary.currentColor()
        case .active:
            return Color.white
        case .filled, .loading:
            return ColorManager.iconDecorativePurpleHeart.currentColor()
        case .error:
            return ColorManager.iconDecorativePersimmon.currentColor()
        }
    }

    var borderColor: Color {
        switch self {
        case .empty:
            return ColorManager.bgSurfaceNeutralSecondary.currentColor()
        case .active, .filled, .loading:
            return ColorManager.iconDecorativePurpleHeart.currentColor()
        case .error:
            return ColorManager.iconDecorativePersimmon.currentColor()
        }
    }

    var scale: CGFloat {
        switch self {
        case .empty, .active:
            return 1.0
        case .filled, .loading, .error:
            return 0.6
        }
    }
}

struct PINCodeDot: View {
    var state: PINCodeDotState

    var body: some View {
        Circle()
            .strokeBorder(state.borderColor, lineWidth: 2)
            .background(Circle().foregroundColor(state.foregroundColor))
            .frame(
                width: Metrics.Sizes.pinCodeCircleSize,
                height: Metrics.Sizes.pinCodeCircleSize
            )
            .scaleEffect(state.scale)
            .animation(.easeOut(duration: 0.3))
            .applySmallShadow()
            .accessibility(label: Text(Localizable.login_pincode_accessibility_label()))
    }
}

struct PINCodeDot_Previews: PreviewProvider {
    static var previews: some View {
        HStack(spacing: 20) {
            PINCodeDot(state: .filled)
            PINCodeDot(state: .active)
            PINCodeDot(state: .empty)
            PINCodeDot(state: .error)
        }
    }
}
