// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct RadioListPickerSection: Identifiable {
    let id: String
    let title: String
    let items: [RadioListPickerItem]
}

protocol RadioListPickerItem {
    var id: String { get }
    var title: String { get }
}

struct RadioListPickerView: View {
    let sections: [RadioListPickerSection]
    @Binding var selectedItemId: String?

    var body: some View {
        CompatibleVStack(alignment: .leading) {
            ForEach(sections) { section in
                Text(section.title)
                    .applyTextStyle(fontStyle: .headlineXS)
                    .padding(.top)
                if section.items.isEmpty {
                    RadioListPickerContainerView(
                        backgroundColor: ColorManager.borderNeutralPrimary.currentColor(),
                        borderColor: .clear
                    ) {
                        Text(Localizable.overview_pick_pregnancy_none())
                            .applyTextStyle(fontStyle: .textM, textColor: ColorManager.textSecondary.currentColor())
                    }
                } else {
                    // Not using Identifiable protocol here, to avoid error for property definition
                    ForEach(section.items, id: \.id) { item in
                        Button(action: {
                            selectedItemId = item.id
                        }, label: {
                            RadioListPickerItemView(
                                title: item.title,
                                selected: selectedItemId == item.id
                            )
                        })
                    }
                }
            }
        }
    }
}

struct RadioListPickerView_Previews: PreviewProvider {
    struct PreviewItem : RadioListPickerItem {
        let id: String
        let title: String
    }

    static var previews: some View {
        RadioListPickerView(
            sections: [
                RadioListPickerSection(
                    id: "1",
                    title: "Section 1",
                    items: (1...2).map({ i in PreviewItem(id: "1_\(i)", title: "Item \(i)")})
                ),
                RadioListPickerSection(
                    id: "2",
                    title: "Section 2",
                    items: (1...3).map({ i in PreviewItem(id: "2_\(i)", title: "Item \(i)")})
                ),
                RadioListPickerSection(
                    id: "3",
                    title: "Section 3",
                    items: []
                )
            ],
            selectedItemId: .constant(nil)
        )
        .padding()
    }
}
