// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct NumberPadKeyboard: View {

    var keyPressed: (NumberPadKeyboardKeyType) -> Void
    let isBioKeyEnabled: Bool

    private var height: CGFloat {
        Metrics.Sizes.numberKeyboardButtonHeight * CGFloat(keyRows().count) + Metrics.Spacing.minimum * CGFloat(keyRows().count - 1)
    }

    init(isBioKeyEnabled: Bool, keyPressed: @escaping (NumberPadKeyboardKeyType) -> Void) {
        self.keyPressed = keyPressed
        self.isBioKeyEnabled = isBioKeyEnabled
    }

    func keyRows() -> [[NumberPadKeyboardKeyType]] {
        [
            (1...3).mapToNumberKeyTypes(),
            (4...6).mapToNumberKeyTypes(),
            (7...9).mapToNumberKeyTypes(),
            [.delete, .number(0), isBioKeyEnabled ? .bio : .empty]
        ]
    }

    var body: some View {
        GeometryReader { geo in
            Group {
                R.color.keyboardSeparator.color()
                    .frame(
                        width: geo.size.width,
                        height: height
                    )
                    .applySmallShadow()
                VStack(spacing: Metrics.Spacing.minimum) {
                    ForEach(keyRows(), id: \.self) { (row) in
                        HStack(spacing: Metrics.Spacing.minimum) {
                            ForEach(row, id: \.self) { (key) in
                                NumberPadKeyboardKey(key: key, activated: keyPressed)
                                    .frame(
                                        width: ceil(geo.size.width / CGFloat(row.count)),
                                        height: Metrics.Sizes.numberKeyboardButtonHeight
                                    )
                            }
                        }
                        .frame(width: geo.size.width)
                    }
                }
            }
            .cornerRadius(8)
        }
        .padding()
    }
}

private extension ClosedRange where Bound == Int {
    func mapToNumberKeyTypes() -> [NumberPadKeyboardKeyType] {
        self.map({ NumberPadKeyboardKeyType.number(UInt($0)) })
    }
}

struct NumberPadKeyboard_Previews: PreviewProvider {
    static var previews: some View {
        Group {
            NumberPadKeyboard(isBioKeyEnabled: true, keyPressed: { _ in })
                .environment(\.colorScheme, .light)
            NumberPadKeyboard(isBioKeyEnabled: true, keyPressed: { _ in })
                .environment(\.colorScheme, .dark)
        }
    }
}
