// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct ProgressBar: View {
    let progress: Double

    private let capsuleHidingDistance: CGFloat = 4

    var body: some View {
        GeometryReader { geo in
            HStack(spacing: 0) {
                Capsule()
                    .fill(ColorManager.iconDecorativePurpleHeart.currentColor())
                    .frame(width:
                            max(0, (geo.size.width * CGFloat(progress)) +
                            (progress > 0 ? capsuleHidingDistance * 2 : 0))
                    )
                    .padding(.leading, -capsuleHidingDistance)
                Spacer()
            }
            .background(ColorManager.borderNeutralPrimary.currentColor())
        }
        .frame(height: 8)
        .clipped()
    }
}

struct ProgressBar_Previews: PreviewProvider {
    static var previews: some View {
        VStack(spacing: 10) {
            ProgressBar(
                progress: 0.0
            )
            ProgressBar(
                progress: 0.33
            )
            ProgressBar(
                progress: 0.5
            )
            ProgressBar(
                progress: 0.7
            )
            ProgressBar(
                progress: 1.0
            )
        }
        .padding()
    }
}
