// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct TitleDescriptionTagVStack: View {
    let title: String
    var titleStyle: FontStyle = .headlineXS
    let description: String?
    var textLineLimit: Int? = 2
    let tag: String?
    
    var body: some View {
        VStack(alignment: .leading) {
            VStack(alignment: .leading) {
                HStack(spacing: 0) {
                    Text(title)
                        .applyTextStyle(fontStyle: titleStyle)
                        .fixedSize(horizontal: false, vertical: true)
                        .lineLimit(2)
                        .multilineTextAlignment(.leading)
                        .frame(maxWidth: .infinity, alignment: .leading)
                    ChevronView(direction: .right)
                }
                Text(description ?? "")
                    .applyTextStyle(fontStyle: .textM)
                    .fixedSize(horizontal: false, vertical: true)
                    .lineLimit(textLineLimit)
                    .multilineTextAlignment(.leading)
                    .frame(maxWidth: .infinity, alignment: .leading)
            }
                Text(tag ?? "")
                .applyTextStyle(fontStyle: .textXS, textColor: ColorManager.textSecondary.currentColor())
        }
    }
}

struct ArticleCategoryCardVStack_Previews: PreviewProvider {
    static var previews: some View {
        VStack {
            TitleDescriptionTagVStack(
                title: "Undersøgelser",
                description: "Vaccinationer, læge, jordemoder og scaninger",
                tag: "0 artikler"
            )
            TitleDescriptionTagVStack(
                title: "Undersøgelser",
                description: "Vaccinationer, læge, jordemoder og scaninger",
                tag: "1 artikler"
            )
            TitleDescriptionTagVStack(
                title: "Undersøgelser",
                description: "Følg med i din graviditet hver uge",
                tag: "2 artikler"
            )
        }
        .padding()
    }
}
