// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct ViewControllerHolder {
    weak var value: UIViewController?
}

struct ViewControllerKey: EnvironmentKey {
    /// Default value is the root view controller. It's okay to use that is most cases.
    static var defaultValue: ViewControllerHolder {
        ViewControllerHolder(value: App.topViewController)
    }
}

extension EnvironmentValues {
    var viewController: UIViewController? {
        get { self[ViewControllerKey.self].value }
        set { self[ViewControllerKey.self].value = newValue }
    }
}

extension UIViewController {

    /// Presents the `PartialSheetView` with provided content
    /// - Parameter content: Content to show
    func presentPartialSheet<Content: View>(
        showCloseButton: Bool = false,
        primaryButton: PartialSheetButton? = nil,
        secondaryButton: PartialSheetButton? = nil,
        @ViewBuilder content: @escaping () -> Content) {
        let toPresent = UIHostingController(rootView: AnyView(EmptyView()))
        toPresent.modalPresentationStyle = .overFullScreen
        toPresent.modalTransitionStyle = .coverVertical
        toPresent.view.backgroundColor = UIColor.clear
        toPresent.rootView = AnyView(
            PartialSheetView(
                showCloseButton: showCloseButton,
                primaryButton: primaryButton,
                secondaryButton: secondaryButton,
                content: content()
            )
            .environment(\.viewController, toPresent)
        )
        self.present(toPresent, animated: false, completion: nil) // Don't animate as the partial view does it! ☝️
    }
}
