// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct ErrorStateView: View {
    let text: String
    let retryAction: () -> Void

    var body: some View {
        VStack(spacing: Metrics.Spacing.space24) {
            Image(R.image.error.errorState.name)
            VStack(spacing: Metrics.Spacing.space12) {
                Text(Localizable.common_alert_title_error())
                    .applyTextStyle(
                        fontStyle: .headlineM,
                        textColor: ColorManager.textPrimary.currentColor()
                    )
                Text(text)
                    .applyTextStyle(
                        fontStyle: .textM,
                        textColor: ColorManager.textPrimary.currentColor()
                    )
                    .lineLimit(.max)

                Button(action: retryAction, label: {
                    Text(Localizable.common_cta_retry())
                        .applyTextStyle(
                            fontStyle: .buttonL,
                            textColor: ColorManager.textInteractivePrimary.currentColor()
                        )
                    }
                )
            }
            .multilineTextAlignment(.center)
        }
        .padding()
    }
}

struct ErrorView_Previews: PreviewProvider {
    static var previews: some View {
        ErrorStateView(
            text: "Dine data kunne ikke hentes. Tjek din internetforbindelse og prøv igen.",
            retryAction: {
            print("Retry!")
        })
    }
}
