// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct ExpandableText: View {
    let text: String
    let maxNumberOfLines: Int
    @Binding var isTruncated: Bool
    @Binding var isExpanded: Bool

    var fontStyle = FontStyle.textM

    private func determineTruncation(_ geometry: GeometryProxy) {
        let font: UIFont = fontStyle.scaledUIFont()
        let textSize: CGRect = text.boundingRect(
            with: CGSize(
                width: geometry.size.width,
                height: .greatestFiniteMagnitude
            ),
            options: .usesLineFragmentOrigin,
            attributes: [.font: font as Any],
            context: nil
        )

        let lineHeight: CGFloat = font.lineHeight
        let linesRoundedUp = Int(ceil(textSize.height / lineHeight))

        isTruncated = linesRoundedUp > maxNumberOfLines
        if !isTruncated {
            isExpanded = false // Force to false, if not truncated
        }
    }

    var body: some View {
        VStack {
            Text(text)
                .applyTextStyle(fontStyle: fontStyle)
                .lineLimit(isExpanded ? nil : maxNumberOfLines)
                .fixedSize(horizontal: false, vertical: true)
                .background(
                    GeometryReader { geometry in
                        Color.clear.onAppear {
                            self.determineTruncation(geometry)
                        }
                    }
                )
        }
    }
}

struct ExpandableText_Previews: PreviewProvider {
    static var previews: some View {
        ExpandableText(
            text: String.loremIpsum(.large),
            maxNumberOfLines: 2,
            isTruncated: .constant(false),
            isExpanded: .constant(false)
        ).padding()
    }
}
