// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import UIKit
import SwiftUI

final class SUILandscapeModalViewController<Content: View>: SUIViewContainerViewController<UIView> {

    private var cancelBag = CancelBag()

    override var shouldAutorotate: Bool {
        true
    }

    private var appDelegate: AppDelegate? {
        UIApplication.shared.delegate as? AppDelegate
    }

    init(@ViewBuilder content: () -> Content) {
        super.init(uiContainerView: UIView())
        self.assignContentToRootView(content())
        self.view.backgroundColor = ColorManager.bgNeutralPrimary.currentUIColor()
    }

    required init?(coder: NSCoder) {
        super.init(coder: coder)
    }

    required init(uiContainerView: UIView) {
        super.init(uiContainerView: uiContainerView)
    }

    override var supportedInterfaceOrientations: UIInterfaceOrientationMask {
        .landscape
    }

    override var preferredInterfaceOrientationForPresentation: UIInterfaceOrientation {
        App.preferredLandscapeOrientation
    }

    override func viewDidLoad() {
        super.viewDidLoad()
        appDelegate?.forceOrientationChange(.landscape)
    }

    override func viewWillDisappear(_ animated: Bool) {
        appDelegate?.forceOrientationChange(.portrait)
        super.viewWillDisappear(animated)
    }
}
