// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import UIKit
import WebKit

struct SUIScrollView<Content: View>: UIViewControllerRepresentable {

    @Binding var currentPage: Int
    let isPaged: Bool
    let bounces: Bool
    let showIndicators: Bool
    let content: Content

    init(currentPage: Binding<Int>?, isPaged: Bool, bounces: Bool, showIndicators: Bool, @ViewBuilder content: () -> Content) {
        self._currentPage = currentPage ?? .constant(-1)
        self.isPaged = isPaged
        self.bounces = bounces
        self.showIndicators = showIndicators
        self.content = content()
    }

    func makeUIViewController(context: Context) -> SUIViewContainerViewController<UIScrollView> {
        let vc = SUIViewContainerViewController(uiContainerView: UIScrollView())
        vc.assignContentToRootView(self.content)
        return vc
    }

    func updateUIViewController(_ viewController: SUIViewContainerViewController<UIScrollView>, context: Context) {
        viewController.assignContentToRootView(self.content)

        viewController.specificTypeView.delegate = context.coordinator
        viewController.specificTypeView.isPagingEnabled = isPaged
        viewController.specificTypeView.showsVerticalScrollIndicator = showIndicators
        viewController.specificTypeView.showsHorizontalScrollIndicator = showIndicators
        viewController.specificTypeView.bounces = bounces
    }

    func makeCoordinator() -> Coordinator {
        Coordinator(currentPage: $currentPage)
    }

    /// Coordinator to handle NSObject requirement for delegate.
    final class Coordinator : NSObject, UIScrollViewDelegate {

        @Binding var currentPage: Int

        init(currentPage: Binding<Int>?) {
            self._currentPage = currentPage ?? .constant(-1)
        }

        func scrollViewDidScroll(_ scrollView: UIScrollView) {
            if currentPage != scrollView.currentPage {
                currentPage = scrollView.currentPage
            }
        }
    }
}
