// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import XCTest
import CMSServices
@testable import MinGraviditet

final class ArticlesIntegrationTests: CMSIntegrationTestCase {
    func testArticles() {
        let articlesService = ArticlesServiceImpl()
        performAndWait(articlesService.fetchArticleCategories()) { (articles) in
            XCTAssertGreaterThan(articles.count, 0)
            XCTAssertGreaterThan(articles.first!.articles.count, 0)
        }
    }

    func testArticlesForWeek19() {
        let articlesService = ArticlesServiceImpl()

        performAndWait(articlesService.fetchArticleCategories(for: 19)) { (articles) in
            XCTAssertGreaterThan(articles.currentWeek.count, 0)
            XCTAssertGreaterThan(articles.currentWeek.first!.articles.count, 0)
            XCTAssertGreaterThan(articles.nextWeek?.count ?? 0, 0)
            XCTAssertGreaterThan(articles.nextWeek?.first?.articles.count ?? 0, 0)
        }
    }

    func testArticleSearch() {
        let articlesService = ArticlesServiceImpl()
        performAndWait(articlesService.search(query: "sundere")) { (articles) in
            XCTAssertTrue(!articles.isEmpty)
        }
    }
}
