// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import XCTest
import DependencyInjection
import CMSServices
import HTTPNetworking
import Combine
import ErrorData
import Logger
@testable import MinGraviditet

/// During a review by Arosii it was requested that the external dependency was integration tested directly against the CMS end points.
/// This is a super class for test cases, which should test the CMS integration.
class CMSIntegrationTestCase : XCTestCase {

    override class func setUp() {
        super.setUp()
        Resolver.shared.allowOverride = true
        Resolver.shared.registerAsSingleton(CMSApiConfiguration.self, CMSConfiguration())
        Resolver.shared.registerAsSingleton(NetworkSession.self, URLSession.shared)
        Resolver.shared.registerAsSingleton(Logger.self, OSLogger())
    }

    override class func tearDown() {
        super.tearDown()
    }

    func performAndWait<T>(_ publisher: AnyPublisher<T, ServiceError>, assertValue: ((T) -> Void)?) {
        var cancelBag = CancelBag()
        let expect = XCTestExpectation(description: "Waiting for CMS publisher...")
        publisher
            .sink(
                receiveCompletion: { completion in
                switch completion {
                case .failure(let error):
                    XCTFail("This shouldn't have failed: \(error)")
                case .finished:
                    expect.fulfill()
                }
            },
            receiveValue: { value in
                assertValue?(value)
            })
            .store(in: &cancelBag)
        wait(for: [expect], timeout: 60.0) // Depending on you current internet connection this can take a long time ...
    }
}
