// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import XCTest
@testable import MinGraviditet

class SequenceTests: XCTestCase {

    func testSortedByKeyPath() {
        let sequence = SequenceTestElement.testSequence()
        let sorted = sequence.sorted(by: \.date)
        XCTAssertEqual(sorted.first?.date, Date(timeIntervalSince1970: 0))
        XCTAssertEqual(sorted.last?.date, Date(timeIntervalSince1970: 7))

        let sorted2 = sequence.sorted(by: \.date, using: >)
        XCTAssertEqual(sorted2.first?.date, Date(timeIntervalSince1970: 7))
        XCTAssertEqual(sorted2.last?.date, Date(timeIntervalSince1970: 0))
    }

    func testMinByKeyPath() {
        let sequence = SequenceTestElement.testSequence()
        let min = sequence.min(by: \.date)
        XCTAssertEqual(min?.date, Date(timeIntervalSince1970: 0))
    }

    func testMaxByKeyPath() {
        let sequence = SequenceTestElement.testSequence()
        let max = sequence.max(by: \.date)
        XCTAssertEqual(max?.date, Date(timeIntervalSince1970: 7))
    }
}

private struct SequenceTestElement {
    let date: Date

    static func testSequence() -> [SequenceTestElement] {
        [
            SequenceTestElement(date: Date(timeIntervalSince1970: 7)),
            SequenceTestElement(date: Date(timeIntervalSince1970: 0)),
            SequenceTestElement(date: Date(timeIntervalSince1970: 2)),
            SequenceTestElement(date: Date(timeIntervalSince1970: 1))
        ]
    }
}
