// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import CMSData
import SharedServices

enum PageType : CaseIterable {
    case consent
    case behindTheApp
    case aboutTheApp
    case myLocking
    case myLog
    case privacyPolicy
    case masterData
    case support
    case wip

    var path: String {
        switch self {
        case .consent: return "lille-samtykke-app-aaben"
        case .behindTheApp: return "bag-appen"
        case .aboutTheApp: return "om-appen"
        case .myLocking: return "min-spaerring"
        case .myLog: return "min-log"
        case .privacyPolicy: return "databeskyttelse"
        case .masterData: return "stamkort"
        case .support: return "support"
        case .wip: return "hvad-arbejder-vi-paa"
        }
    }
}

struct PageRequest: CMSRequest {
    typealias ResponseType = DefaultEntityResponse<Page>

    var pathComponents: [String] { [ "page", pageType.path ] }

    let apiConfiguration: CMSApiConfiguration

    let pageType: PageType

    init(apiConfiguration: CMSApiConfiguration, pageType: PageType) {
        self.apiConfiguration = apiConfiguration
        self.pageType = pageType
    }
}

