public struct SearchResultDomain: Codable {
    public let title: String
    public let categoryName: String
    public let categoryIcon: String
    public let content: String
    public let reference: SearchResultDomainReference
    public let articleId: Int
    public let articleName: String?
    
    public init(
        title: String,
        categoryName: String,
        categoryIcon: String,
        content: String,
        reference: SearchResultDomainReference,
        articleId: Int,
        articleName: String?
    ) {
        self.title = title
        self.categoryName = categoryName
        self.categoryIcon = categoryIcon
        self.content = content
        self.reference = reference
        self.articleId = articleId
        self.articleName = articleName
    }
}

public enum SearchResultDomainReference: Codable {
    case Article
    case ArticleSection(sectionId: Int)
}

public extension SearchResultDomain {
    var infoText: String {
        if let articleName = articleName {
            return "\(categoryName) • \(articleName)"
        }
        return categoryName
    }
    
    var id: Int {
        switch reference {
        case .Article:
            return articleId
        case .ArticleSection(let id):
            return id
        }
    }
    
    var highlightedSectionId: Int? {
        switch reference {
        case .Article:
            return nil
        case .ArticleSection(let id):
            return id
        }
    }
}
