// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import Combine
import CMSData
import ErrorData
import SharedServices

public final class ChecklistContentServiceMock : ChecklistContentService {
    public init() { }

    public func fetchChecklistContent() -> AnyPublisher<[ChecklistContent], ServiceError> {
        let contents = (1...10)
            .map({ i in
                ChecklistContent(
                    id: i,
                    title: "Checklist \(i)",
                    text: (0...Int.random(in: 5...30)).map({_  in "text"}).joined(separator: " "),
                    items: (0...Int.random(in: 2...10)).map({ itemI in
                        ChecklistItemContent(
                            id: "\(i)-\(itemI)",
                            title: "Item \(itemI)",
                            text: Bool.random() ? (0...Int.random(in: 2...15)).map({_  in "text"}).joined(separator: " ") : nil
                        )
                    })
                )
            })
        return MockPublisher.mockFailable(
            value: contents,
            error: ServiceError.networkError(.missingInternetConnection)
        )
    }
}
