// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import Combine
import CMSData
import ErrorData
import SharedServices

public final class PagesServiceMock: PagesService {
    public init() { }

    private func mockedPage(title: String) -> Page {
        Page(
            title: title,
            content: (0..<Int.random(in: 10...500)).map({ _ in "text"}).joined(separator: " ").capitalized,
            excerpt: nil,
            slug: nil
        )
    }

    public func fetchConsent() -> AnyPublisher<Page, ServiceError> {
        page(for: .consent)
    }

    public func fetchBehindTheApp() -> AnyPublisher<Page, ServiceError> {
        page(for: .behindTheApp)
    }

    public func fetchAboutTheApp() -> AnyPublisher<Page, ServiceError> {
        page(for: .aboutTheApp)
    }

    public func fetchMyLocking() -> AnyPublisher<Page, ServiceError> {
        page(for: .myLocking)
    }

    public func fetchMyLog() -> AnyPublisher<Page, ServiceError> {
        page(for: .myLog)
    }

    public func fetchPrivacyPolicy() -> AnyPublisher<Page, ServiceError> {
        page(for: .privacyPolicy)
    }

    public func fetchMasterData() -> AnyPublisher<Page, ServiceError> {
        page(for: .masterData)
    }

    public func fetchSupport() -> AnyPublisher<Page, ServiceError> {
        page(for: .support)
    }
    
    public func fetchWorkInProgress() -> AnyPublisher<Page, ServiceError> {
        page(for: .wip)
    }

    private func page(for type: PageType) -> AnyPublisher<Page, ServiceError> {
        return MockPublisher.mockFailable(
            value: mockedPage(title: type.path.capitalized),
            error: ServiceError.networkError(.missingInternetConnection)
        )
    }
}
