// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import Combine
import ErrorData
import SharedServices
import GMAppData

final public class ConfigurationServiceMock: ConfigurationService {
    private var checkedIds: [String: Set<String>] = [:]
    private var dateOfBirths: [String: Date] = [:]

    public init() { }

    public func fetchChecklists(maternityId: String) -> AnyPublisher<[String], ServiceError> {
        MockPublisher.mockFailable(value: Array(checkedIds[maternityId, default: []]), error: ServiceError.networkError(.missingInternetConnection))
    }

    public func updateChecklistItem(maternityId: String, itemId: String, isChecked: Bool) -> AnyPublisher<Void, ServiceError> {
        if checkedIds[maternityId] == nil {
            checkedIds[maternityId] = []
        }
        if isChecked {
            checkedIds[maternityId]?.insert(itemId)
        } else {
            checkedIds[maternityId]?.remove(itemId)
        }
        return MockPublisher.mockFailable(value: Void(), error: ServiceError.networkError(.missingInternetConnection))
    }

    public func dateOfBirth(maternityId: String) -> AnyPublisher<DateOfBirth, ServiceError> {
        MockPublisher.mockFailable(
            value: DateOfBirth(dateOfBirth: dateOfBirths[maternityId]),
            error: ServiceError.failedToParseJson
        )
    }

    public func updateDateOfBirth(maternityId: String, date: Date?) -> AnyPublisher<DateOfBirth, ServiceError> {
        if let date = date {
            dateOfBirths[maternityId] = date
        } else {
            dateOfBirths.removeValue(forKey: maternityId)
        }
        return MockPublisher.mockFailable(
            value: DateOfBirth(dateOfBirth: dateOfBirths[maternityId]),
            error: ServiceError.networkError(.missingInternetConnection)
        )
    }

    public func deleteAllData() -> AnyPublisher<Void, ServiceError> {
        self.checkedIds.removeAll()
        self.dateOfBirths.removeAll()
        return MockPublisher.mockFailable(
            value: Void(),
            error: ServiceError.failedToParseJson
        )
    }
}
