// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation

public final class UserSettingsServiceMock : UserSettingsService {
    private (set) var values: [String: Any] = [:]
    private var isPersistant: Bool = false

    public init(isPersistant: Bool = false) {
        self.isPersistant = isPersistant
    }

    public func save<T>(_ value: T, for key: UserSettingsKey<T>) {
        if isPersistant {
            UserDefaults.standard.set(value, forKey: key.mockId)
            UserDefaults.standard.synchronize()
        } else {
            values[key.id] = value
        }
    }

    public func get<T>(key: UserSettingsKey<T>) -> T? {
        if isPersistant {
            return UserDefaults.standard.value(forKey: key.mockId) as? T
        } else {
            return values[key.id] as? T
        }
    }

    public func remove<T>(key: UserSettingsKey<T>) {
        if isPersistant {
            UserDefaults.standard.removeObject(forKey: key.mockId)
            UserDefaults.standard.synchronize()
        } else {
            values.removeValue(forKey: key.id)
        }
    }
}

extension UserSettingsKey {
    var mockId: String {
        "mock_\(id)"
    }
}
