// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import Combine
import XCTest
import DependencyInjection
import Logger
import CMSData
import ErrorData
import HTTPMockHelpers
@testable import HTTPNetworking
@testable import CMSServices

final class ChecklistContentServiceImplTests: CMSURLSessionMockTestCase {
    private let checklistService = ChecklistContentServiceImpl()

    private let testData = [
        ChecklistContent(
            id: 0,
            title: "Title 1",
            text: "Text 1",
            items: [
                ChecklistItemContent(
                    id: "id-1",
                    title: "Item Title 1",
                    text: "Item text 1"
                )
            ])
    ]

    func testFetchArticleCategories() {
        let url = URL(string: "\(Self.config.cmsBaseUrl)/checklist")!
        URLSessionStubResults.resultsForUrls[url] = .dataResponse(
            data: try! JSONEncoder.iso8601().encode(testData),
            response:  URLSessionStubResponses.response(url: url)!
        )
        let expect = XCTestExpectation()
        checklistService.fetchChecklistContent()
            .sink(
                receiveCompletion: { self.handleSubscriberCompletion($0, expectation: expect) },
                receiveValue: { checklistContent in
                    XCTAssertEqual(1, checklistContent.count)
                }
            ).store(in: &cancelBag)

        wait(for: [expect], timeout: 1.0)
    }
}
